! *************************************************************************************************
! sue_data.f90
! Data handling routines
! *************************************************************************************************



MODULE sue_data


  USE sue_config
  USE sue_lib
  USE sue_co2calc
  IMPLICIT NONE
  SAVE


CONTAINS


! *************************************************************************************************
! *** DATA LOADING PROCEDURES *********************************************************************
! *************************************************************************************************


! ************************************
! *** LOAD IN MODEL PARAMETER FILE ***
! ************************************
  SUBROUTINE load_par()
    IMPLICIT NONE
! local variables
    INTEGER::in=5
    CHARACTER(LEN=255)::dummy_string
    CHARACTER(LEN=11)::verify_string
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"sue_par.dat",action="read")

! *** read in parameter data ***
! "SUE INPUT PARAMETER FILE"
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
    READ(unit=in,FMT='(A24)')      dummy_string
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "MODEL CONFIGURATION: MISC"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_bio)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_sed)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_gaia)
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "MODEL CONFIGURATION: FORCINGS"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_ocir)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_sealevel)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_SST)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_SSS)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_SSPO4)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_I)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_seaice)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_swind)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_terr_C)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_neri_CaCO3)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_neri_opal)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_fdust)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,forcingopt(fopt_sig_fSi)
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "MODEL CONFIGURATION: INTEGRATION CONTROL"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_load_modelstate)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_save_modelstate)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_chain_modelstate)
    READ(unit=in,FMT='(A60,I1)')   dummy_string,par_int_scheme
    READ(unit=in,FMT='(A60,I4)')   dummy_string,t_spin_max
    READ(unit=in,FMT='(A60,I4)')   dummy_string,t_ice_init
    READ(unit=in,FMT='(A60,I4)')   dummy_string,par_n_t_int
    READ(unit=in,FMT='(A60,I4)')   dummy_string,par_n_t_np
    READ(unit=in,FMT='(A60,I4)')   dummy_string,par_t_dt
    READ(unit=in,FMT='(A60,I4)')   dummy_string,t_print
    READ(unit=in,FMT='(A60,I4)')   dummy_string,t_ice_save
    READ(unit=in,FMT='(A60,I4)')   dummy_string,t_ice_chain
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "NEW PRODUCTION: MISC"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_np_alt)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_np_latinsol)
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_kT_Q10_dia
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_kT_Q10_coc
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_dSSPO4_dia
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_dSSPO4_coc
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_PO4_0_dia
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_PO4_0_coc 
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_Fe_0_dia 
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_Fe_0_coc  
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_Si_0_dia   
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_Si_0_coc 
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_bionp_frac_DOM_dia
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_bionp_frac_DOM_coc
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_bionp_kconv
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_bionp_DOM_tconst
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_misc_SSPO4_tconst
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "NEW PRODUCTION: REDFIELD RATIOS"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_np_fixed_FetoC_dia)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_np_fixed_FetoC_coc)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_np_fixed_Corgtoopal_dia)
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Porg_Norg
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Porg_Corg
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Porg_O2
    READ(unit=in,FMT='(A60,F9.1)') dummy_string,par_red_Feorg_Corg_dia
    READ(unit=in,FMT='(A60,F9.1)') dummy_string,par_red_Feorg_Corg_coc
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Corg_opal_dia
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Corg_cal_coc
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Corg_arg_coc
    READ(unit=in,FMT='(A60,F9.1)') dummy_string,par_red_Feorg_Corg_dia_max
    READ(unit=in,FMT='(A60,F9.1)') dummy_string,par_red_Feorg_Corg_coc_max
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Corg_opal_dia_var_r0
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Corg_opal_dia_var_Fe0
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_red_Corg_opal_dia_var_dFe
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "NEW PRODUCTION: REMINERALIZATION"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_remin_Corg_alt)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_remin_cal_alt)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_remin_arg_alt)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_remin_opal_alt)
    READ(unit=in,FMT='(A60,F9.3)') dummy_string,par_remin_eL_Corg
    READ(unit=in,FMT='(A60,F9.3)') dummy_string,par_remin_eL_cal
    READ(unit=in,FMT='(A60,F9.3)') dummy_string,par_remin_eL_arg
    READ(unit=in,FMT='(A60,F9.3)') dummy_string,par_remin_eL_opal
    READ(unit=in,FMT='(A60,F9.3)') dummy_string,par_remin_pL_Corg
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_remin_pP_Corg
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_remin_fracrecal_Corg
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_remin_fracrecal_cal
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_remin_opal_vel
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_remin_opal_K
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_remin_O2_min
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "NEW PRODUCTION: ISOTOPIC FRACTIONATION"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_d13Corg_alt)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_d13CaCO3_fp)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_d13CaCO3_fb)
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_13C_DIC_Corg_dia
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_13C_DIC_Corg_coc
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_13C_DIC_Corg_ef_dia
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_bionp_13C_DIC_Corg_ef_coc
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "IRON!"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_scav_Fe_alt)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,bioopt(bopt_uniform_frac_Fe_dis)
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_frac_dust_Fe
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_frac_Fe_dis
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_apparsol_Fe
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_k_scav_Fe
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_k_scav_Fe_fPMlaw_Corg
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_k_scav_Fe_fPMlaw_opal
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_k_scav_Fe_fPMlaw_cal
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_k_scav_Fe_fPMlaw_arg
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_k_scav_Fe_fPMlaw_refrac
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_conv_Fe_tot_inorg
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "SEDIMENTS: MISC"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_save_wtper)
    READ(unit=in,FMT='(A60,I2)')   dummy_string,n_sed_mix
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_sed_presfrac_Corg
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_sed_presfrac_FeO
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_frefrac
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_sed_mix_kmax
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_sed_lys_thresh
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "SEDIMENTS: CACO3 DIAGENESIS"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_diagen_lookup_CaCO3)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_diagen_respir)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_rdis_fixed)
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_sed_interf_th
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_caldis_k
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_caldis_exp
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_argdis_k
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_argdis_exp
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_sed_fraci
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_sed_diagenfrac_Corg
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "SEDIMENTS: OPAL DIAGENESIS"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_diagen_lookup_opal)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_diagen_AltoasymSi)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_diagen_AltoKSi)
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_sed_opal_Sitoopalmax
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_sed_opal_KSi0
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "SEDIMENTS: SUB-SYSTEM"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_14C)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sed_mix)
    READ(unit=in,FMT='(A60,I2)')   dummy_string,n_sed_com_min
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_sed_top_th
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_sed_poros
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_sed_poros_top
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "SEDIMENTS: USER-DEFINABLE CORES"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_sedcor)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sedcor_14C)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sedcor_mix)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_sedcor_fixedacc)
    READ(unit=in,FMT='(A60,I2)')   dummy_string,n_sedcor_com_min
    READ(unit=in,FMT='(A60,I4)')   dummy_string,n_sedcor
    READ(unit=in,FMT='(A60,I4)')   dummy_string,n_sedcor_tot
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_sedcor_top_th
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_sedcor_poros
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_sedcor_poros_top
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "GAIA SUB-SYSTEM: MISC"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,gaiaopt(gopt_uniform_frac_SiO2_dis)
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_frac_dust_SiO2
    READ(unit=in,FMT='(A60,F8.6)') dummy_string,par_frac_SiO2_dis
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_gaia_riv(it_CO2) 
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_gaia_riv(it_alk)
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_gaia_riv(it_Si)
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_gaia_vol(it_CO2)
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_gaia_vol(it_alk)
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_gaia_misc(it_CO2)
    READ(unit=in,FMT='(A60,F6.3)') dummy_string,par_gaia_misc(it_alk)
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_gaia_frac_riv_sur
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_gaia_frac_vol_sur
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_gaia_frac_misc_sur
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "GAIA SUB-SYSTEM: TERRESTRIAL CARBON STORAGE"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,gaiaopt(gopt_ext_sig_Cterr)
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_frac_terr_atm
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_frac_terr_sur
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "GAIA SUB-SYSTEM: NERITIC SEDIMENTS STORAGE"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,gaiaopt(gopt_ext_sig_CaCO3)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,gaiaopt(gopt_ext_sig_opal)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,gaiaopt(gopt_neri_CaCO3_reefal_dsealevel)
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_gaia_frac_neri_sur
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_CaCO3_reefal_racc
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_CaCO3_reefal_rero
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_CaCO3_reefal_maxD
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_CaCO3_nonreefal_racc
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_CaCO3_nonreefal_rero
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_CaCO3_nonreefal_maxD
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_opal_racc
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_opal_rero
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_gaia_neri_opal_maxD
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "GAIA SUB-SYSTEM: ISOTOPIC SIGNITURES"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_gaia_13C_vol
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_gaia_13C_riv
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_gaia_13C_neri
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_gaia_13C_misc
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_gaia_13C_terr
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "MISC: MISC"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,miscopt(mopt_Alatlon)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,miscopt(mopt_conv_dw_maxD)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,miscopt(mopt_uniform_kgastrans)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,miscopt(mopt_uniform_vdif)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,miscopt(mopt_conv_adj)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,miscopt(mopt_d13atm_alt)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,miscopt(mopt_co2calc_alt)
    READ(unit=in,FMT='(A60,I4)')   dummy_string,par_n_wflux
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_kgastrans_coeff_CO2
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_misc_kgastrans_vel_O2
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_vdif
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_hdif
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_misc_conv_adj_max
    READ(unit=in,FMT='(A60,F5.3)') dummy_string,par_misc_conv_Ithresh
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_SS_tconst
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_SSO2_tconst
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_conv_dT
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_conv_Tmin
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_conv_dS
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_misc_conv_Smax
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "MISC: DATA SAVE"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_save_box_data_ind)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_save_sed_data_ind)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_save_sedsysdata)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_save_sedfnpdata)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_save_sedcorfnpdata)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_save_seddisdata)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,sedopt(sopt_save_sedcordisdata)
    READ(unit=in,FMT='(A60,I4)')   dummy_string,par_t_ice_save_1
    READ(unit=in,FMT='(A60,I4)')   dummy_string,par_t_ice_save_2
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
! "DEBUG OPTIONS"
    READ(unit=in,FMT='(A60)')      dummy_string
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_warn)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_debug_main)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_debug_box)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_debug_sed)
    READ(unit=in,FMT='(A60,A1)')   dummy_string,runopt(ropt_debug_sed_lib)
    READ(unit=in,FMT='(A60,F7.3)') dummy_string,par_boxfracmassex_threshold
    READ(unit=in,FMT='(A60,F8.3)') dummy_string,par_dtot_per_threshold
! ""
    READ(unit=in,FMT='(A1)')       dummy_string
    READ(unit=in,FMT='(A1)')       dummy_string
    READ(unit=in,FMT='(A11)')      verify_string

    CLOSE(unit=in)


! check that the input parameter file data matches up with the READ sequence
    IF (.NOT. (verify_string == "END-OF-DATA")) THEN
      PRINT*,""
      PRINT*,"FATAL ERROR [sue_data.f90, load_par]:"
      PRINT*,"end of input parameter file data does not match up with the READ sequence"
      PRINT*,""
      STOP
    ENDIF

! check the number of integration time steps requested
    IF (par_n_t_int > n_t_int_max) THEN
      PRINT*,""
      PRINT*,"FATAL ERROR [sue_data.f90, load_par]:"
      PRINT*,"the number of integration time steps must be <= ",n_t_int_max
      PRINT*,""
      STOP
    ENDIF

! check the number of np time steps requested per integration time step
    IF (par_n_t_np > n_t_np_max) THEN
      PRINT*,""
      PRINT*,"FATAL ERROR [sue_data.f90, load_par]:"
      PRINT*,"the number of new production steps per integration step must be <= ",n_t_np_max
      PRINT*,""
      STOP
    ENDIF

! check the total number of np time steps requested
    IF ((par_n_t_int * par_n_t_np) > n_t_np_max) THEN
      PRINT*,""
      PRINT*,"FATAL ERROR [sue_data.f90, load_par]:"
      PRINT*,"the total number of new production time steps"
      PRINT*,"(i.e., (number of integration time steps per year) * (number of new production sub-step)"
      PRINT*,"must be <= ",n_t_np_max
      PRINT*,""
      STOP
    ENDIF

! check the sea-air d13C scheme option selected
    IF ( &
      & (miscopt(mopt_d13atm_alt) <> "1") .AND. &
      & (miscopt(mopt_d13atm_alt) <> "2") .AND. &
      & (miscopt(mopt_d13atm_alt) <> "3") .AND. &
      & (miscopt(mopt_d13atm_alt) <> "4") &
      & ) THEN
      PRINT*,""
      PRINT*,"FATAL ERROR [sue_data.f90, load_par]:"
      PRINT*,"option number is out of range; selected = ",miscopt(mopt_d13atm_alt)
      PRINT*,""
      STOP
    ENDIF

! check that the restoring times are less than or equal to the model time step
    IF ( &
      & ((conv_yr_d / REAL(par_n_t_int,KIND=fp_1)) > par_misc_SSPO4_tconst) .OR. &
      & ((conv_yr_d / REAL(par_n_t_int,KIND=fp_1)) > par_misc_SS_tconst) .OR.    &
      & ((conv_yr_d / REAL(par_n_t_int,KIND=fp_1)) > par_misc_SSO2_tconst)       &
      & ) THEN
      PRINT*,""
      PRINT*,"FATAL ERROR [sue_data.f90, load_par]:"
      PRINT*,"all restoring time values (d) must be >= ",(conv_yr_d / REAL(par_n_t_int,KIND=fp_1))
      PRINT*,""
      STOP
    ENDIF

! check that the number of requested user-definable sediment cores is at least 1, if that option is selected
    IF ((runopt(ropt_sedcor) == yes) .AND. (n_sedcor == 0)) n_sedcor = 1

! calculate phytoplankton temperature-dependent growth factor a1
    par_bionp_kT_a1_dia = LOG(par_bionp_kT_Q10_dia) / 10.0
    par_bionp_kT_a1_coc = LOG(par_bionp_kT_Q10_coc) / 10.0

! calculate maximum depth (m) required in order to calculate neritic sediment accumulation
    par_n_bath_depth_neri = 150 + &
      & INT(MAX(par_gaia_neri_CaCO3_reefal_maxD,par_gaia_neri_CaCO3_nonreefal_maxD,par_gaia_neri_opal_maxD))

! *** adjust units ***
! calculate gaian isotope fluxes
    par_gaia_riv(it_13C_CO2)  = calc_frac_13C(par_gaia_13C_riv)  * par_gaia_riv(it_CO2)
    par_gaia_vol(it_13C_CO2)  = calc_frac_13C(par_gaia_13C_vol)  * par_gaia_vol(it_CO2)
    par_gaia_misc(it_13C_CO2) = calc_frac_13C(par_gaia_13C_misc) * par_gaia_misc(it_CO2)
! convert gaian units - (Tmol yr-1) to (mol yr-1)
    par_gaia_riv(:)  = 1.0E+12 * par_gaia_riv(:)
    par_gaia_vol(:)  = 1.0E+12 * par_gaia_vol(:)
    par_gaia_misc(:) = 1.0E+12 * par_gaia_misc(:)
! convert 'apparent' solubility of Fe, from (nmol kg-1) to (mol kg-1)
    par_apparsol_Fe = conv_nmol_mol * par_apparsol_Fe
! convert variable diatom Si:C [Fe] parameters from (nmol kg-1) to (mol kg-1)
    par_red_Corg_opal_dia_var_dFe = conv_nmol_mol * par_red_Corg_opal_dia_var_dFe
    par_red_Corg_opal_dia_var_Fe0 = conv_nmol_mol * par_red_Corg_opal_dia_var_Fe0
! convert base POM nutrient export rate from (umol kg-1 yr-1) to (mol kg-1 yr-1)
    par_bionp_dSSPO4_dia = conv_umol_mol * par_bionp_dSSPO4_dia
    par_bionp_dSSPO4_coc = conv_umol_mol * par_bionp_dSSPO4_coc
! convert Michalis-Menton half-saturation values to (mol kg-1)
    par_bionp_PO4_0_dia     = conv_umol_mol * par_bionp_PO4_0_dia
    par_bionp_PO4_0_coc     = conv_umol_mol * par_bionp_PO4_0_coc
    par_bionp_Fe_0_dia      = conv_nmol_mol * par_bionp_Fe_0_dia
    par_bionp_Fe_0_coc      = conv_nmol_mol * par_bionp_Fe_0_coc
    par_bionp_Si_0_dia      = conv_umol_mol * par_bionp_Si_0_dia
    par_bionp_Si_0_coc      = conv_umol_mol * par_bionp_Si_0_coc
! convert +ve values in parameter file to their true -ve sign
    par_bionp_13C_DIC_Corg_dia = -1.0 * par_bionp_13C_DIC_Corg_dia
    par_bionp_13C_DIC_Corg_coc = -1.0 * par_bionp_13C_DIC_Corg_coc
    par_remin_pP_Corg          = -1.0 * par_remin_pP_Corg
    par_gaia_13C_terr          = -1.0 * par_gaia_13C_terr
! convert (umol cm-2)-1 to (mol m-2)-1
    par_k_scav_Fe_fPMlaw_Corg = (1.0 / (conv_umol_mol / conv_cm2_m2)) * par_k_scav_Fe_fPMlaw_Corg
    par_k_scav_Fe_fPMlaw_opal = (1.0 / (conv_umol_mol / conv_cm2_m2)) * par_k_scav_Fe_fPMlaw_opal
    par_k_scav_Fe_fPMlaw_cal  = (1.0 / (conv_umol_mol / conv_cm2_m2)) * par_k_scav_Fe_fPMlaw_cal
    par_k_scav_Fe_fPMlaw_arg  = (1.0 / (conv_umol_mol / conv_cm2_m2)) * par_k_scav_Fe_fPMlaw_arg
! convert (g m-2)-1 to (g cm-2)-1
    par_k_scav_Fe_fPMlaw_refrac = (1.0 / (1.0 / conv_m2_cm2)) * par_k_scav_Fe_fPMlaw_refrac
! set total flux-dependent scavenging rate
    par_k_scav_Fe_fPMlaw_tot = 1.0E-06 + &
      & par_k_scav_Fe_fPMlaw_Corg      + &
      & par_k_scav_Fe_fPMlaw_opal      + &
      & par_k_scav_Fe_fPMlaw_cal       + &
      & par_k_scav_Fe_fPMlaw_arg
! convert (g cm-2 kyr-1) to (g cm-2 yr-1)
    par_frefrac = conv_yr_kyr * par_frefrac
! convert (umol kg-1) to (mol kg-1)
    par_remin_O2_min  = conv_umol_mol * par_remin_O2_min
! convert opal dissolution rate constant from (yr-1) to (s-1)
    par_sed_opal_KSi0 = par_sed_opal_KSi0 / conv_yr_s
! convert verticaly eddy diffusivity from (cm2 s-1) to (m2 yr-1)
    par_misc_vdif = conv_cm2_m2 * conv_yr_s * par_misc_vdif
! convert horizontal eddy diffusivity from (10^6 cm2 s-1) to (m2 yr-1)
    par_misc_hdif = conv_cm2_m2 * conv_yr_s * 1.0E+06 * par_misc_hdif
! convert (d) to (yr)
    par_misc_SS_tconst    = conv_d_yr * par_misc_SS_tconst
    par_misc_SSO2_tconst  = conv_d_yr * par_misc_SSO2_tconst
    par_misc_SSPO4_tconst = conv_d_yr * par_misc_SSPO4_tconst
! (%) to (fraction)
    par_boxfracmassex_threshold = par_boxfracmassex_threshold / 100.0

  END SUBROUTINE load_par
! ************************************
  

! ******************************************
! *** load in multi-box ocean parameters ***
! ******************************************
  SUBROUTINE load_ocean_par(oceancir,PIGoatracer,PIGphys,oconvadjfixed)
    IMPLICIT NONE
! dummy arguments
    TYPE(ocean_circulation),DIMENSION(n_wflux_max),INTENT(INOUT)::oceancir
    TYPE(ocean_atm_tracer),INTENT(inout)::PIGoatracer
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_col,n_lay,n_phys)::PIGphys
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_col,n_lay,n_t_int_max)::oconvadjfixed
! local variables
    INTEGER::in=5,x=0,v=0
    INTEGER::c,l,t
    REAL(KIND=fp_1)::PIG_T
    REAL(KIND=fp_1)::PIG_S
    REAL(KIND=fp_1)::PIG_CO2
    REAL(KIND=fp_1)::PIG_alk
    REAL(KIND=fp_1)::PIG_PO4
    REAL(KIND=fp_1)::PIG_Si
    REAL(KIND=fp_1)::PIG_Fe
    REAL(KIND=fp_1)::PIG_O2
    REAL(KIND=fp_1)::PIG_d13C_CO2
    REAL(KIND=fp_1)::PIG_d18O_O2
    REAL(KIND=fp_1)::PIG_DOC
    REAL(KIND=fp_1)::PIG_d13C_DOC
    REAL(KIND=fp_1),DIMENSION(n_col,n_lay)::PIG_lay_th ! PIG ocean layer thickness
    REAL(KIND=fp_1),DIMENSION(n_col,n_lay)::PIG_vdif   ! PIG ocean vertical eddy diffusivity
    REAL(KIND=fp_1),DIMENSION(n_col,n_lay,n_t_int_max)::PIG_conv ! PIG ocean convective adjustment
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_surA         ! PIG ocean surface area
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_lat          ! PIG ocean surface mid-point latitude
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_dlat         ! PIG ocean surface mid-point latitudinal width
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_lon          ! PIG ocean surface mid-point longitude
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_dlon         ! PIG ocean surface mid-point longitudinal width
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_conv_dw      ! PIG ocean allow deep-water formation?
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_conv_mixD    ! PIG ocean maximum mixed layer depth
    REAL(KIND=fp_1),DIMENSION(n_col)::PIG_remin_topD   ! PIG ocean upper-most remineralization depth

! *** initialize local arrays ***
    PIG_lay_th(:,:) = 0.0
    PIG_vdif(:,:)   = 0.0
    PIG_conv(:,:,:) = 0.0
    PIG_surA(:)     = 0.0
    
! *** load in ocean circulation details ***
! check file format
    CALL check_fileformat(par_n_wflux,modelname//"_input/"//modelname//"_o_cir.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname//"_o_cir.dat",action="read")
! read in ocean circulation vectors
    DO v = 1,par_n_wflux
! read in start column, start layer, end column, end layer, water mass flux (Sv)
      READ(unit=in,FMT='(4I3,2F8.3)') & 
	& oceancir(v)%ioc_cs, &
	& oceancir(v)%ioc_ls, &
	& oceancir(v)%ioc_ce, &
	& oceancir(v)%ioc_le, &
	& oceancir(v)%ioc_wf_1, &
	& oceancir(v)%ioc_wf_2
! convert units of Sv (10^6 m3 s-1) to kg yr-1
      oceancir(v)%ioc_wf_1 = conv_yr_s * 1.0E+06 * conv_m3_kg * oceancir(v)%ioc_wf_1
      oceancir(v)%ioc_wf_2 = conv_yr_s * 1.0E+06 * conv_m3_kg * oceancir(v)%ioc_wf_2
! set default present ocean circulation water flux
      oceancir(v)%ioc_wf = 0.0
    END DO
! close file pipe
    CLOSE(unit=in)
    
! *** load in ocean surface latitude-longitude data ***
! check file format
    CALL check_fileformat(4,modelname//"_input/"//modelname_col//"_o_latlon.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_o_latlon.dat",action="read")
! read in ocean surface latitude-longitude data
    READ(unit=in,FMT='(99F9.3)') (PIG_lat(c),c=1,n_col)
    READ(unit=in,FMT='(99F9.3)') (PIG_dlat(c),c=1,n_col)
    READ(unit=in,FMT='(99F9.3)') (PIG_lon(c),c=1,n_col)
    READ(unit=in,FMT='(99F9.3)') (PIG_dlon(c),c=1,n_col)
! close file pipe
    CLOSE(unit=in)
! set latitude-longitude data equally for all ocean layers
    DO l = 1,n_lay
      PIGphys(:,l,ip_lat)  = PIG_lat(:)
      PIGphys(:,l,ip_dlat) = PIG_dlat(:)
      PIGphys(:,l,ip_lon)  = PIG_lon(:)
      PIGphys(:,l,ip_dlon) = PIG_dlon(:)
    END DO

! *** load in ocean surface area ***
    IF (miscopt(mopt_Alatlon) == no) THEN
! check file format
      CALL check_fileformat(1,modelname//"_input/"//modelname_col//"_o_surA.dat")
! open file pipe
      OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_o_surA.dat",action="read")
! read in maximum (PIG) ocean surface area (m2)
! NOTE: this is the maximum box surface area, not necessarily the ocean surface or ocean bottom area
! i.e., the area cross-section of the column
      READ(unit=in,FMT='(99E10.3)') (PIG_surA(c),c=1,n_col)
! close file pipe
      CLOSE(unit=in)
    ENDIF
! set maximum potential (PIG) area equally for all ocean layers
    DO l = 1,n_lay
      PIGphys(:,l,ip_A_top) = PIG_surA(:)
      PIGphys(:,l,ip_A_bot) = PIG_surA(:)
    END DO
    
! *** load in ocean layer thickness ***
! check file format
    CALL check_fileformat(n_lay,modelname//"_input/"//modelname//"_o_lay_th.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname//"_o_lay_th.dat",action="read")
! read in ocean layer thicknesses
    DO l = 1,n_lay
      READ(unit=in,FMT='(99F9.3)') (PIG_lay_th(c,l),c=1,n_col)
    END DO
! close file pipe
    CLOSE(unit=in)
! calculate ocean layer top and bottom depths
    DO c = 1,n_col
      PIGphys(c,1,ip_D_top) = 0.0
      PIGphys(c,1,ip_D_bot) = PIG_lay_th(c,1)
      DO l = 2,n_lay
	PIGphys(c,l,ip_D_top) = PIGphys(c,l - 1,ip_D_top) + PIG_lay_th(c,l - 1)
	PIGphys(c,l,ip_D_bot) = PIGphys(c,l - 1,ip_D_bot) + PIG_lay_th(c,l)
      ENDDO
    END DO
    
! *** load in ocean vertical eddy diffusivity ***
! set vertical eddy diffusivities
! NOTE: 'par_misc_vdif' is already in units of (m2 yr-1)
    IF (miscopt(mopt_uniform_vdif) == yes) THEN
      PIGphys(:,:,ip_vdif) = par_misc_vdif
    ELSE
! check file format
      CALL check_fileformat(n_lay - 1,modelname//"_input/"//modelname//"_o_vdif.dat")
! open file pipe
      OPEN(unit=in,file=modelname//"_input/"//modelname//"_o_vdif.dat",action="read")
! read in ocean vertical eddy diffusivities (cm2 s-1)
      DO l = 1,n_lay - 1
	READ(unit=in,FMT='(99F7.3)') (PIG_vdif(c,l),c=1,n_col)
      END DO
! close file pipe
      CLOSE(unit=in)
! set global PIG physics array values convert units from (cm2 s-1) to (m2 yr-1)
      PIGphys(:,:,ip_vdif) = conv_cm2_m2 * conv_yr_s * PIG_vdif(:,:)
    ENDIF
    
! *** load in ocean convective adjustment data ***
! check file format
    CALL check_fileformat((n_lay - 1) * par_n_t_int,modelname//"_input/"//modelname//"_o_conv.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname//"_o_conv.dat",action="read")
! read in ocean convective adjustment data (yr-1)
    DO t = 1,par_n_t_int
      DO l = 1,n_lay - 1
	READ(unit=in,FMT='(99F10.3)') (PIG_conv(c,l,t),c=1,n_col)
      END DO
    END DO
! close file pipe
    CLOSE(unit=in)
! set global PIG physics array values
    oconvadjfixed(:,:,:) = PIG_conv(:,:,:)
! NOTE: in units of (total number of convective adjustments per year)
    DO c = 1,n_col
      DO l = 1,n_lay
	PIGphys(c,l,ip_conv) = SUM(PIG_conv(c,l,:)) / n_t_int_max
      END DO
    END DO

! *** load in ocean deep-water formation factor data ***
! check file format
    CALL check_fileformat(1,modelname//"_input/"//modelname_col//"_o_conv_dw.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_o_conv_dw.dat",action="read")
! read in ocean deep-water formation data
    READ(unit=in,FMT='(99F6.3)') (PIG_conv_dw(c),c=1,n_col)
! close file pipe
    CLOSE(unit=in)
! set global PIG physics array values
    DO l = 1,n_lay
      PIGphys(:,l,ip_conv_dw) = PIG_conv_dw(:)
    END DO
    
! *** load in ocean 'mixed layer' depth data ***
! check file format
    CALL check_fileformat(1,modelname//"_input/"//modelname_col//"_o_conv_mixD.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_o_conv_mixD.dat",action="read")
! read in ocean mixed layer depth data (m)
    READ(unit=in,FMT='(99F9.3)') (PIG_conv_mixD(c),c=1,n_col)
! close file pipe
    CLOSE(unit=in)
! set global PIG physics array values
    DO l = 1,n_lay
      PIGphys(:,l,ip_conv_mixD) = PIG_conv_mixD(:)
    END DO
    
! *** load in ocean upper remineralization depth data ***
! check file format
    CALL check_fileformat(1,modelname//"_input/"//modelname_col//"_o_remin_topD.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_o_remin_topD.dat",action="read")
! read in ocean mixed layer depth data (m)
    READ(unit=in,FMT='(99F9.3)') (PIG_remin_topD(c),c=1,n_col)
! close file pipe
    CLOSE(unit=in)
! set global PIG physics array values
    DO l = 1,n_lay
      PIGphys(:,l,ip_remin_topD) = PIG_remin_topD(:)
    END DO
    
! *** load in PIG ocean tracer details ***
! check file format
    CALL check_fileformat(12,modelname//"_input/"//"suexxxx_o_tracer.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_o_tracer.dat",action="read")
! read in PIG average ocean tracer values
    READ(unit=in,FMT='(E11.3)') PIG_T
    READ(unit=in,FMT='(E11.3)') PIG_S
    READ(unit=in,FMT='(E11.3)') PIG_CO2
    READ(unit=in,FMT='(E11.3)') PIG_PO4
    READ(unit=in,FMT='(E11.3)') PIG_alk
    READ(unit=in,FMT='(E11.3)') PIG_Si
    READ(unit=in,FMT='(E11.3)') PIG_Fe
    READ(unit=in,FMT='(E11.3)') PIG_O2
    READ(unit=in,FMT='(E11.3)') PIG_d13C_CO2
    READ(unit=in,FMT='(E11.3)') PIG_d18O_O2
    READ(unit=in,FMT='(E11.3)') PIG_DOC
    READ(unit=in,FMT='(E11.3)') PIG_d13C_DOC
! close file pipe
    CLOSE(unit=in)
! set PIG tracer array values
    PIGoatracer%ioat_t(:,:,it_T)       = PIG_T
    PIGoatracer%ioat_t(:,:,it_S)       = PIG_S
    PIGoatracer%ioat_t(:,:,it_CO2)     = PIG_CO2
    PIGoatracer%ioat_t(:,:,it_PO4)     = PIG_PO4
    PIGoatracer%ioat_t(:,:,it_alk)     = PIG_alk
    PIGoatracer%ioat_t(:,:,it_Si)      = PIG_Si
    PIGoatracer%ioat_t(:,:,it_Fe)      = PIG_Fe
    PIGoatracer%ioat_t(:,:,it_O2)      = PIG_O2
    PIGoatracer%ioat_t(:,:,it_13C_CO2) = calc_frac_13C(PIG_d13C_CO2) * PIG_CO2
    PIGoatracer%ioat_t(:,:,it_18O_O2)  = calc_frac_18O(PIG_d18O_O2)  * PIG_O2
    PIGoatracer%ioat_t(:,:,it_DOC)     = PIG_DOC
    PIGoatracer%ioat_t(:,:,it_13C_DOC) = calc_frac_13C(PIG_d13C_DOC) * PIG_DOC
    
  END SUBROUTINE load_ocean_par
! ****************************************
  
  
! *************************************
! *** load in atmosphere parameters ***
! *************************************
  SUBROUTINE load_atm_par(PIGoatracer)
    IMPLICIT NONE
! dummy arguments
    TYPE(ocean_atm_tracer),INTENT(inout)::PIGoatracer
! local variables
    INTEGER::x=1,in=5
    REAL(KIND=fp_1)::PIG_pCO2
    REAL(KIND=fp_1)::PIG_pO2
    REAL(KIND=fp_1)::PIG_d13C_pCO2
    REAL(KIND=fp_1)::PIG_d18O_pO2
! check file format
    CALL check_fileformat(4,modelname//"_input/"//"suexxxx_a_tracer.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_a_tracer.dat",action="read")
! read in ocean circulation data
    READ(unit=in,FMT='(E11.3)') PIG_pCO2
    READ(unit=in,FMT='(E11.3)') PIG_pO2
    READ(unit=in,FMT='(E11.3)') PIG_d13C_pCO2
    READ(unit=in,FMT='(E11.3)') PIG_d18O_pO2
! close file pipe
    CLOSE(unit=in)
! set PIG tracer array values
    PIGoatracer%ioat_a(ia_pCO2)     = PIG_pCO2
    PIGoatracer%ioat_a(ia_pO2)      = PIG_pO2
    PIGoatracer%ioat_a(ia_13C_pCO2) = calc_frac_13C(PIG_d13C_pCO2) * PIG_pCO2
    PIGoatracer%ioat_a(ia_18O_pO2)  = calc_frac_18O(PIG_d18O_pO2)  * PIG_pO2
  END SUBROUTINE load_atm_par
! ************************************
  
  
! ******************************************************
! *** load in sediment sub-layer mixing rate profile ***
! ******************************************************
  SUBROUTINE load_sed_mix_k(sedmixk)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_sed_mix)::sedmixk
! local variables
    INTEGER::d
    INTEGER::in=5
    CHARACTER(LEN=255)::dummy_string
    REAL(KIND=fp_1)::topsed_mix_k
! check file format
    CALL check_fileformat(n_sed_mix + 1,modelname//"_input/"//"suexxxx_sed_mix_k.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sed_mix_k.dat",action="read")
! read mixed-layer sediment mixing profile (top down)
! NOTE: the mixing rate at the top of the sediment stack will correspond to an index value of 'n_sed_mix',
!       because of restrictions in the sediment coupling subroutine
! NOTE: mixing rate units from data file are (cm2 kyr-1)
! NOTE: the sediment mixing depth number was been reduced by one when the model parameter data was loaded, 
!       because the first mixing value in the mixing profile file is used to mix the 
!       top ('well-mixed') sediment layer with the top 1cm of the underlying sediment stack
! NOTE: read in the top ('well-mixed') sediment layer to stack top mixing rate first,
!       this value is placed in the index=0 position in the array
    READ(unit=in,FMT='(F11.3)') sedmixk(0)
    DO d = n_sed_mix,1,-1
      READ(unit=in,FMT='(F11.3)') sedmixk(d)
    END DO
    CLOSE(unit=in)
! normalize mixing rate profile with the set maximum mixing rate corresponding to unity in the loaded profile
    sedmixk(:)   = par_sed_mix_kmax * sedmixk(:)
! change mixing rate units from (cm2 kyr-1) to (cm2 yr-1)
    sedmixk(:)   = conv_yr_kyr * sedmixk(:)
! check that the maximum mixing rate in the profile does not exceed the maximum rate 
! that can be accomodated by the mixing algorithm
    IF (MAXVAL(sedmixk(:)) > 0.5) THEN
      PRINT*,"FATAL ERROR [sue_data.f90, load_sed_mix_k]:"
      PRINT*,"mixing time-step weighted sediment mixing rate is too large"
      PRINT*,"maximum mixing rate in profile (cm2 yr-1) = ",MAXVAL(sedmixk(:))
      STOP
    ENDIF
  END SUBROUTINE load_sed_mix_k
! ******************************************************


! ********************************************
! *** LOAD IN SPECMAP d18O DATA  FROM FILE ***
! ********************************************
  SUBROUTINE load_specmap_d18O(spec)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_kyr)::spec
! local variables
    INTEGER::n=0,in=5,year=0
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sig_d18O.dat",action="read")
! read in data
    DO n=0,n_kyr
      READ(unit=in,FMT='(I5,F10.3)') year,spec(n)
    END DO
    CLOSE(unit=in)
  END SUBROUTINE load_specmap_d18O
! ********************************************
  

! **********************************************
! *** SEDIMENT DEPTH INTERVAL DATA FROM FILE ***
! **********************************************
  SUBROUTINE load_sed_depth(sedpar)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_col,n_sed_depth,n_sed_par)::sedpar
! local variables
    INTEGER::m=0,in=5
    REAL(KIND=fp_1)::D_top,D_bot
! check file format
    CALL check_fileformat(n_sed_depth,modelname//"_input/"//"suexxxx_sed_depth.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sed_depth.dat",action="read")
! read in data
    DO m = 1,n_sed_depth
      READ(unit=in,FMT='(2F10.3)') D_top,D_bot
      sedpar(:,m,ised_par_D_PIG_top) = D_top
      sedpar(:,m,ised_par_D_PIG_bot) = D_bot
      sedpar(:,m,ised_par_D_PIG_mid) = (D_top + D_bot) / 2.0
    END DO
! close file pipe
    CLOSE(unit=in)
  END SUBROUTINE load_sed_depth
! ************************************


! ****************************************
! *** load in sediment core parameters ***
! ****************************************
  SUBROUTINE load_sedcor_par(sedcorpar)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_sedcor,n_sed_par)::sedcorpar
! local variables
    INTEGER::in=5,p=0
    INTEGER::c
    REAL(KIND=fp_1)::D,dthdt_1_cal,dthdt_1_refrac,dthdt_2_cal,dthdt_2_refrac
! check file format
    CALL check_fileformat(n_sedcor,modelname//"_input/"//"suexxxx_sedcor.dat")
! open file pipe    
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sedcor.dat",action="read")
! read in core parameter data
! NOTE: fixed user-defined sediment core accumulation rate is in units of (g cm-2 kyr-1)
    DO p = 1,n_sedcor
      READ(unit=in,FMT='(I5,F10.3,4F8.3)') c,D,dthdt_1_cal,dthdt_1_refrac,dthdt_2_cal,dthdt_2_refrac
      sedcorpar(p,ised_par_colnum)      = REAL(c,KIND=fp_1)
      sedcorpar(p,ised_par_D_PIG_mid)   = D
      sedcorpar(p,ised_par_sedcor_f1_cal)    = dthdt_1_cal
      sedcorpar(p,ised_par_sedcor_f1_refrac) = dthdt_1_refrac
      sedcorpar(p,ised_par_sedcor_f2_cal)    = dthdt_2_cal
      sedcorpar(p,ised_par_sedcor_f2_refrac) = dthdt_2_refrac
    END DO
! close file pipe
    CLOSE(unit=in)
! set derived parameters
! NOTE: set the top and bottom depths of the sediment core slightly offset from the mid depth,
!       to avoid possible divide-by-zero errors elsewhere in the program,
!       despite the fact that the sediment core layers do not actually span a non-zero ocean depth interval
    sedcorpar(:,ised_par_D_PIG_top) = sedcorpar(:,ised_par_D_PIG_mid) - 0.001
    sedcorpar(:,ised_par_D_PIG_bot) = sedcorpar(:,ised_par_D_PIG_mid) + 0.001
! change units of fixed user-defined sediment core accumulation rate from (g cm-2 kyr-1) to (g cm-2 yr-1)
    sedcorpar(:,ised_par_sedcor_f1_cal)    = conv_yr_kyr * sedcorpar(:,ised_par_sedcor_f1_cal)
    sedcorpar(:,ised_par_sedcor_f1_refrac) = conv_yr_kyr * sedcorpar(:,ised_par_sedcor_f1_refrac)
    sedcorpar(:,ised_par_sedcor_f2_cal)    = conv_yr_kyr * sedcorpar(:,ised_par_sedcor_f2_cal)
    sedcorpar(:,ised_par_sedcor_f2_refrac) = conv_yr_kyr * sedcorpar(:,ised_par_sedcor_f2_refrac)
  END SUBROUTINE load_sedcor_par
! ****************************************


! *****************************************
! *** LOAD IN BATHYMETRY DATA FROM FILE ***
! *****************************************
  SUBROUTINE load_bathdata(bathdata)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_bath_depth,n_bath_par)::bathdata
! local variables
    INTEGER::c=0,p=0,in=5
    REAL(KIND=fp_1)::depth
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_bath.dat",action="read")
! read in data
! NOTE: there should be a column of ocean bottom area fraction for each water column 
! NOTE: after reading in across the data, the depths should be set for all the column bathymetries
    DO p = 1,n_bath_depth
      READ(unit=in,FMT='(E8.1,99E16.9)') depth,(bathdata(c,p,ibath_Afrac),c=1,n_col)
      bathdata(:,p,ibath_D) = depth
    END DO
! close file pipe
    CLOSE(unit=in)
! add a small area fraction to each bathymetric depth interval 
! NOTE: this is to ensure that when sediment system areas are calculated, 
!       none of them have zero area
    bathdata(:,:,ibath_Afrac) = 0.999994 * (bathdata(:,:,ibath_Afrac) + 1.0E-09)
  END SUBROUTINE load_bathdata
! *****************************************


! *******************************************
! *** LOAD FIXED MAGNITUDE NEW PRODUCTION ***
! *******************************************
  SUBROUTINE load_bionp_fixed(bionpfixed)
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_col,n_bionp)::bionpfixed
! local variables
    INTEGER::c
    INTEGER::in=5
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_Corg_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_Corg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_cal_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_arg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_opal_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_Feorg_tot
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_Corg_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_Corg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_cal_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_arg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_DOC_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_DOC_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_DOFe_tot
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_DOC_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_DOC_coc

! *** load in basic fixed magnitude new production variables ***
! NOTE: np fluxes in (umol cm-2 yr-1) except Feorg in (nmol cm-2 yr-1), and d13C in (o/oo)
! NOTE: the order of input of data from file is (one per line)
!       (01) Corg       - dia
!       (02) Corg       - coc
!       (03) cal        - coc
!       (04) arg        - coc
!       (05) opal       - dia
!       (06) Feorg      - tot
!       (07) d13C(Corg) - dia
!       (08) d13C(Corg) - coc
!       (09) d13C(cal)  - coc
!       (10) d13C(arg)  - arg
! check file format
    CALL check_fileformat(15,modelname//"_input/"//modelname_col//"_bionp.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_bionp.dat",action="read")
! read in data
    READ(unit=in,FMT='(99F10.3)') (bionp_Corg_dia(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_Corg_coc(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_cal_coc(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_arg_coc(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_opal_dia(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_Feorg_tot(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_d13C_Corg_dia(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_d13C_Corg_coc(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_d13C_cal_coc(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_d13C_arg_coc(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_DOC_dia(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_DOC_coc(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_DOFe_tot(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_d13C_DOC_dia(c),c=1,n_col)
    READ(unit=in,FMT='(99F10.3)') (bionp_d13C_DOC_coc(c),c=1,n_col)
! close file pipe
    CLOSE(unit=in)

! *** change units ***
! NOTE: convert all np fluxes to (mol m-2 yr-1)
    DO c = 1,n_col
      bionpfixed(c,ibionp_Corg_dia)     = conv_umol_mol * bionp_Corg_dia(c) / conv_cm2_m2
      bionpfixed(c,ibionp_Corg_coc)     = conv_umol_mol * bionp_Corg_coc(c) / conv_cm2_m2
      bionpfixed(c,ibionp_cal_coc)      = conv_umol_mol * bionp_cal_coc(c) / conv_cm2_m2
      bionpfixed(c,ibionp_arg_coc)      = conv_umol_mol * bionp_arg_coc(c) / conv_cm2_m2
      bionpfixed(c,ibionp_opal_dia)     = conv_umol_mol * bionp_opal_dia(c) / conv_cm2_m2
      bionpfixed(c,ibionp_Feorg_tot)    = conv_nmol_mol * bionp_Feorg_tot(c) / conv_cm2_m2
      bionpfixed(c,ibionp_13C_Corg_dia) = calc_frac_13C(bionp_d13C_Corg_dia(c)) * &
	& bionpfixed(c,ibionp_Corg_dia)
      bionpfixed(c,ibionp_13C_Corg_coc) = calc_frac_13C(bionp_d13C_Corg_coc(c)) * &
	& bionpfixed(c,ibionp_Corg_coc)
      bionpfixed(c,ibionp_13C_cal_coc)  = calc_frac_13C(bionp_d13C_cal_coc(c)) * &
	& bionpfixed(c,ibionp_cal_coc)
      bionpfixed(c,ibionp_13C_arg_coc)  = calc_frac_13C(bionp_d13C_arg_coc(c)) * &
	& bionpfixed(c,ibionp_arg_coc)
      bionpfixed(c,ibionp_DOC_dia)      = conv_umol_mol * bionp_DOC_dia(c) / conv_cm2_m2
      bionpfixed(c,ibionp_DOC_coc)      = conv_umol_mol * bionp_DOC_coc(c) / conv_cm2_m2
      bionpfixed(c,ibionp_DOFe_tot)     = conv_nmol_mol * bionp_DOFe_tot(c) / conv_cm2_m2
      bionpfixed(c,ibionp_13C_DOC_dia)  = calc_frac_13C(bionp_d13C_DOC_dia(c)) * &
	& bionpfixed(c,ibionp_DOC_dia)
      bionpfixed(c,ibionp_13C_DOC_coc)  = calc_frac_13C(bionp_d13C_DOC_coc(c)) * &
	& bionpfixed(c,ibionp_DOC_coc)
    END DO

  END SUBROUTINE load_bionp_fixed
! *******************************************


! *******************************************
! *** LOAD IRON SOLUBILITY DATA FROM FILE ***
! *******************************************
  SUBROUTINE load_dust_Fe_dis(fdustFedis)
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_col)::fdustFedis
! local variables
    INTEGER::c
    INTEGER::in=5
    
! *** load in Fe solubility fraction in atmospheric dust deposited to the surface ocean ***
! NOTE: fraction is in (% soluable)
! check file format
    CALL check_fileformat(1,modelname//"_input/"//modelname_col//"_dust_Fe_dis.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_dust_Fe_dis.dat",action="read")
! read in data
    READ(unit=in,FMT='(99F8.3)') (fdustFedis(c),c=1,n_col)
! close file pipe
    CLOSE(unit=in)
! convert units from (%) to (fraction)
    fdustFedis = 0.01 * fdustFedis
    
  END SUBROUTINE load_dust_Fe_dis
! *******************************************


! *******************************************************************
! *** LOAD SURFACE OCEAN AEOLIAN VARIABILITY FIELD DATA FROM FILE ***
! *******************************************************************
  SUBROUTINE load_dust_survar(fdustsurvar)
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_col)::fdustsurvar
! local variables
    INTEGER::c
    INTEGER::in=5
    
! *** load in glacail-interglacial surface ocean aeolian deposition variability factor ***
! NOTE: 1.0 = full glacial-interglacial variability
! check file format
    CALL check_fileformat(1,modelname//"_input/"//modelname_col//"_dust_survar.dat")
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_dust_survar.dat",action="read")
! read in data
    READ(unit=in,FMT='(99F8.3)') (fdustsurvar(c),c=1,n_col)
! close file pipe
    CLOSE(unit=in)
    
  END SUBROUTINE load_dust_survar
! *******************************************************************


! *******************************************************
! *** LOAD IN OCEAN CIRCULATION SIGNAL DATA FROM FILE ***
! *******************************************************
  SUBROUTINE load_sig_ocir(sigocir)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr)::sigocir
! local variables
    INTEGER::t
    INTEGER::in=5

! *** load in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sig_o_cir.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,F9.3)') dummy_integer,sigocir(t)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_ocir) == yes) THEN
	READ(unit=in,FMT='(I5,F9.3)') dummy_integer,sigocir(t)
      ELSE
	sigocir(t) = sigocir(0)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)

  END SUBROUTINE load_sig_ocir
! *******************************************************


! ************************************************
! *** LOAD IN WIND SPEED SIGNAL DATA FROM FILE ***
! ************************************************
  SUBROUTINE load_sig_swind(sigswind)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigswind
! local variables
    INTEGER::t,c
    INTEGER::in=5
    CHARACTER(LEN=2)::colnum

! *** read in data ***
! NOTE: wind speed in (m s-1)
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_swind.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigswind(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_swind) == yes) THEN
	READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigswind(t,c),c=1,n_col)
      ELSE
	sigswind(t,:) = sigswind(0,:) 
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)

  END SUBROUTINE load_sig_swind
! ************************************************


! *****************************************************
! *** LOAD IN GLOBAL SEALEVEL SIGNAL DATA FROM FILE ***
! *****************************************************
  SUBROUTINE load_sig_sealevel(sigsealevel)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr)::sigsealevel
! local variables
    INTEGER::t
    INTEGER::in=5

! *** load in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sig_sealevel.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,F9.3)') dummy_integer,sigsealevel(t)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_sealevel) == yes) THEN
	READ(unit=in,FMT='(I5,F9.3)') dummy_integer,sigsealevel(t)
      ELSE
	sigsealevel(t) = sigsealevel(0)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)

  END SUBROUTINE load_sig_sealevel
! *****************************************************


! ****************************************************************
! *** LOAD IN TERRESTRIAL CARBON STORAGE SIGNAL DATA FROM FILE ***
! ****************************************************************
  SUBROUTINE load_sig_terr_C(sigterr)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_tracer)::sigterr
! local variables
    INTEGER::t
    INTEGER::in=5

! *** load in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sig_terr_C.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,F10.5)') dummy_integer,sigterr(t,it_CO2)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_terr_C) == yes) THEN
	READ(unit=in,FMT='(I5,F10.5)') dummy_integer,sigterr(t,it_CO2)
      ELSE
	sigterr(t,it_CO2) = sigterr(0,it_CO2)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)
! convert units (GtC to mol)
    sigterr(:,it_CO2) = sigterr(:,it_CO2) * 1.0E+12 * conv_C_kg_mol
! calculate 13C
    sigterr(:,it_13C_CO2) = calc_frac_13C(par_gaia_13C_terr) * sigterr(:,it_CO2)

  END SUBROUTINE load_sig_terr_C
! ****************************************************************


! *********************************************************************
! *** LOAD IN NERITIC SEDIMENTS CACO3 STORAGE SIGNAL DATA FROM FILE ***
! *********************************************************************
  SUBROUTINE load_sig_neri_CaCO3(signeri)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_tracer)::signeri
! local variables
    INTEGER::t
    INTEGER::in=5

! *** load in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sig_neri_CaCO3.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,F10.3)') dummy_integer,signeri(t,it_CO2)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_neri_CaCO3) == yes) THEN
	READ(unit=in,FMT='(I5,F10.3)') dummy_integer,signeri(t,it_CO2)
      ELSE
	signeri(t,it_CO2) = signeri(0,it_CO2)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)
! convert units (10^15 mol to mol)
    signeri(:,it_CO2) = signeri(:,it_CO2) * 1.0E+15
! calculate 13C
    signeri(:,it_13C_CO2) = calc_frac_13C(par_gaia_13C_neri) * signeri(:,it_CO2)
! calculate alk
    signeri(:,it_alk) = 2.0 * signeri(:,it_CO2)

  END SUBROUTINE load_sig_neri_CaCO3
! *********************************************************************


! ********************************************************************
! *** LOAD IN NERITIC SEDIMENTS OPAL STORAGE SIGNAL DATA FROM FILE ***
! ********************************************************************
  SUBROUTINE load_sig_neri_opal(signeri)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_tracer)::signeri
! local variables
    INTEGER::t
    INTEGER::in=5
    
! *** load in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sig_neri_opal.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,F10.3)') dummy_integer,signeri(t,it_Si)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_neri_opal) == yes) THEN
	READ(unit=in,FMT='(I5,F10.3)') dummy_integer,signeri(t,it_Si)
      ELSE
	signeri(t,it_Si) = signeri(0,it_Si)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)
! convert units (10^15 mol to mol)
    signeri(:,it_Si) = signeri(:,it_Si) * 1.0E+15

  END SUBROUTINE load_sig_neri_opal
! ********************************************************************


! *****************************************************************
! *** LOAD IN OCEAN (SURFACE) TEMPERATURE SIGNAL DATA FROM FILE ***
! *****************************************************************
  SUBROUTINE load_sig_SST(sigSST)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigSST
! local variables
    INTEGER::c,t
    INTEGER::in=5

! *** read in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_SST.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigSST(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_SST) == yes) THEN
	READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigSST(t,c),c=1,n_col)
      ELSE
	sigSST(t,:) = sigSST(0,:)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)

  END SUBROUTINE load_sig_SST
! *****************************************************************


! ***********************************************************
! *** LOAD IN OCEAN (SURFACE) [PO4] SIGNAL DATA FROM FILE ***
! ***********************************************************
  SUBROUTINE load_sig_SSPO4(sigSSPO4)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigSSPO4
! local variables
    INTEGER::c,t
    INTEGER::in=5
    
! *** read in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_SSPO4.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigSSPO4(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_SSPO4) == yes) THEN
	READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigSSPO4(t,c),c=1,n_col)
      ELSE
	sigSSPO4(t,:) = sigSSPO4(0,:)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)
! change unit from (umol kg-1) to (mol kg-1)
    sigSSPO4(:,:) = conv_umol_mol * sigSSPO4(:,:)

  END SUBROUTINE load_sig_SSPO4
! ***********************************************************


! **************************************************************
! *** LOAD IN OCEAN (SURFACE) SALINITY SIGNAL DATA FROM FILE ***
! **************************************************************
  SUBROUTINE load_sig_SSS(sigSSS)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigSSS
! local variables
    INTEGER::c,t
    INTEGER::in=5

! *** read in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_SSS.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigSSS(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_SSS) == yes) THEN
	READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigSSS(t,c),c=1,n_col)
      ELSE
	sigSSS(t,:) = sigSSS(0,:)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)

  END SUBROUTINE load_sig_SSS
! **************************************************************


! ****************************************************************
! *** LOAD IN OCEAN (SURFACE) INSOLATION SIGNAL DATA FROM FILE ***
! ****************************************************************
  SUBROUTINE load_sig_I(sigI)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigI
! local variables
    INTEGER::c,t
    INTEGER::in=5
    
! *** read in data ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_I.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigI(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_I) == yes) THEN
	READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigI(t,c),c=1,n_col)
      ELSE
	sigI(t,:) = sigI(0,:)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)
    
  END SUBROUTINE load_sig_I
! ****************************************************************


! ****************************************************
! *** LOAD IN SEA ICE EXTENT SIGNAL DATA FROM FILE ***
! ****************************************************
  SUBROUTINE load_sig_seaice(sigseaicemin,sigseaicemax)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigseaicemin
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigseaicemax
! local variables
    INTEGER::c,t
    INTEGER::in=5
    
! *** read in data - minimum (summer) extent ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_seaice_min.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigseaicemin(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_seaice) == yes) THEN
	READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigseaicemin(t,c),c=1,n_col)
      ELSE
	sigseaicemin(t,:) = sigseaicemin(0,:)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)

! *** read in data - maximum (winter) extent ***
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_seaice_max.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigseaicemax(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_seaice) == yes) THEN
	READ(unit=in,FMT='(I5,99F9.3)') dummy_integer,(sigseaicemax(t,c),c=1,n_col)
      ELSE
	sigseaicemax(t,:) = sigseaicemax(0,:)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)
    
  END SUBROUTINE load_sig_seaice
! ****************************************************


! ******************************************************************
! *** LOAD IN TERREGENEOUS DUST DEPOSITION SIGNAL DATA FROM FILE ***
! ******************************************************************
  SUBROUTINE load_sig_fdust(sigfdust)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr,n_col)::sigfdust
! local variables
    INTEGER::c,t
    INTEGER::in=5
    
! *** read in data ***
! NOTE: units of (g m-2 yr-1)
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//modelname_col//"_sig_fdust.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99E10.3)') dummy_integer,(sigfdust(t,c),c=1,n_col)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_fdust) == yes) THEN
	READ(unit=in,FMT='(I5,99E10.3)') dummy_integer,(sigfdust(t,c),c=1,n_col)
      ELSE
	sigfdust(t,:) = sigfdust(0,:)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)

! *** change units ***
! change dust flux units from (g m-2 yr-1) to (g cm-2 yr-1)
    sigfdust(:,:) = conv_cm2_m2 * sigfdust(:,:)

  END SUBROUTINE load_sig_fdust
! ******************************************************************


! ****************************************************************
! *** LOAD IN Si (WEATHERING) FLUX INPUT SIGNAL DATA FROM FILE ***
! ****************************************************************
  SUBROUTINE load_sig_fSi(sigfSi)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(0:n_kyr)::sigfSi
! local variables
    INTEGER::c,t
    INTEGER::in=5
    
! *** read in data ***
! NOTE: units of (Tmol Si a-1)
! open file pipe
    OPEN(unit=in,file=modelname//"_input/"//"suexxxx_sig_fSi.dat",action="read")
! read in first line of data (t = 0)
    t = 0
    READ(unit=in,FMT='(I5,99F10.3)') dummy_integer,sigfSi(t)
! read in remainder of data, or fill out array with t = 0 values, as required
    DO t = 1,n_kyr
      IF (forcingopt(fopt_sig_fSi) == yes) THEN
	READ(unit=in,FMT='(I5,99E10.3)') dummy_integer,sigfSi(t)
      ELSE
	sigfSi(t) = sigfSi(0)
      END IF
    END DO
! close file pipe
    CLOSE(unit=in)
    
! *** change units ***
! change dust flux units from (Tmol Si a-1) to (mol Si a-1)
    sigfSi(:) = 1.0E12 * sigfSi(:)

  END SUBROUTINE load_sig_fSi
! ******************************************************************


! **********************************************************
! *** LOAD IN SEDIMENT DIAGENESIS LOOK-UP TABLES - CACO3 ***
! **********************************************************
  SUBROUTINE load_sed_dis_lookup_CaCO3()
    IMPLICIT NONE
! local variables
    INTEGER::a,b,c,d,e
    INTEGER::in=5
    
! *** read in calcite dissolution look-up data ***
    OPEN(unit=in,file="/hpc/data/e709916/lookuptable_datafiles/lookup_calcite_4.dat",action="read")
! read in data
    DO a = lookup_i_D_min,lookup_i_D_max,1
      DO b = lookup_i_dCO3_min,lookup_i_dCO3_max,1
	DO d = lookup_i_frac_min,lookup_i_frac_max,1
	  DO e = lookup_i_fCorg_min,lookup_i_fCorg_max,1
	    READ(unit=in,FMT='(F7.3)') lookup_sed_dis_cal(a,b,d,e)
	  END DO
	END DO
      END DO
    END DO
! close file pipe
    CLOSE(unit=in)
! change units from (umol cm-2 yr-1) to (mol cm-2 yr-1)
    lookup_sed_dis_cal(:,:,:,:) = lookup_sed_dis_cal(:,:,:,:) * conv_umol_mol

! *** read in aragonite dissolution look-up data ***
! open file pipe
    OPEN(unit=in,file="/hpc/data/e709916/lookuptable_datafiles/lookup_aragonite_4.dat",action="read")
! read in data
    DO a = lookup_i_D_min,lookup_i_D_max,1
      DO b = lookup_i_dCO3_min,lookup_i_dCO3_max,1
	DO d = lookup_i_frac_min,lookup_i_frac_max,1
	  DO e = lookup_i_fCorg_min,lookup_i_fCorg_max,1
	    READ(unit=in,FMT='(F7.3)') lookup_sed_dis_arg(a,b,d,e)
	  END DO
	END DO
      END DO
    END DO
! close file pipe
    CLOSE(unit=in)
! change units from (umol cm-2 yr-1) to (mol cm-2 yr-1)
    lookup_sed_dis_arg(:,:,:,:) = lookup_sed_dis_arg(:,:,:,:) * conv_umol_mol

  END SUBROUTINE load_sed_dis_lookup_CaCO3
! **********************************************************


! *********************************************************
! *** LOAD IN SEDIMENT DIAGENESIS LOOK-UP TABLES - OPAL ***
! *********************************************************
  SUBROUTINE load_sed_dis_lookup_opal()
    IMPLICIT NONE
! local variables
    INTEGER::a,b,c,d,e
    INTEGER::in=5

! *** read in opal dissolution look-up data ***
! open file pipe
    OPEN(unit=in,file="/hpc/data/e709916/lookuptable_datafiles/lookup_opal.dat",action="read")
! read in data
    DO a = lookup_i_opalpc_min,lookup_i_opalpc_max,1
      DO b = lookup_i_concSi_min,lookup_i_concSi_max,1
	DO c = lookup_i_T_min,lookup_i_T_max,1
	  DO d = lookup_i_KSi0_min,lookup_i_KSi0_max,1
	    DO e = lookup_i_opaltorefrac_min,lookup_i_opaltorefrac_max,1
	      READ(unit=in,FMT='(F7.3)') lookup_sed_dis_opal(a,b,c,d,e)
	    END DO
	  END DO
	END DO
      END DO
    END DO
! close file pipe
    CLOSE(unit=in)
! change units from (umol cm-2 yr-1) to (mol cm-2 yr-1)
    lookup_sed_dis_opal(:,:,:,:,:) = lookup_sed_dis_opal(:,:,:,:,:) * 1.0E-06
    
  END SUBROUTINE load_sed_dis_lookup_opal
! *********************************************************


! *************************************************************************************************



! *************************************************************************************************
! *** DATA SAVING PROCEDURES **********************************************************************
! *************************************************************************************************

  
! *************************************************************
! *** save new production latitude-explicit insolation data ***
! *************************************************************
  SUBROUTINE save_seas_t_np_all(tsave)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::tsave
! local variables
    INTEGER::c
    INTEGER::t
    INTEGER::out=1
    CHARACTER(LEN=3)::tsave_string
    CHARACTER(LEN=255)::filename

! *** create filename identifier string ***
    IF (tsave <= 9) THEN
      WRITE(tsave_string(3:3),'(i1)')tsave
      tsave_string(1:2) = "00"
    ELSE IF (tsave <= 99) THEN
      WRITE(tsave_string(2:3),'(i2)')tsave
      tsave_string(1:1) = "0"
    ELSE
      WRITE(tsave_string(1:3),'(i3)')tsave
    ENDIF

! *** save insolation data ***
! open file pipe
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_misc_I.res"
    OPEN(unit=out,file=filename,action="WRITE")
! write data
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F11.6)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_insol(t,c),c=1,n_col)
    END DO
! close file pipe
    CLOSE(unit=out)

! *** save seaice extent data ***
! open file pipe
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_misc_seaice.res"
    OPEN(unit=out,file=filename,action="WRITE")
! write data
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F11.6)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_seaice(t,c),c=1,n_col)
    END DO
! close file pipe
    CLOSE(unit=out)

! *** save SS [PO4] data ***
! open file pipe
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_surxx_SSPO4.res"
    OPEN(unit=out,file=filename,action="WRITE")
! write data
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F11.6)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (conv_mol_umol * seas_t_np_dSS(t,c,it_PO4),c=1,n_col)
    END DO
! close file pipe
    CLOSE(unit=out)

! *** save SS [Si] data ***
! open file pipe
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_surxx_SSSi.res"
    OPEN(unit=out,file=filename,action="WRITE")
! write data
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F11.6)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (conv_mol_umol * seas_t_np_dSS(t,c,it_Si),c=1,n_col)
    END DO
! close file pipe
    CLOSE(unit=out)

! *** save SS [Fe] data ***
! open file pipe
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_surxx_SSFe.res"
    OPEN(unit=out,file=filename,action="WRITE")
! write data
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F11.6)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (conv_mol_nmol * seas_t_np_dSS(t,c,it_Fe),c=1,n_col)
    END DO
! close file pipe
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of umol Corg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_dia_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_Corg_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_dia_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
      & t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
      & (calc_d13C(seas_t_np_dnp(t,c,ibionp_Corg_dia),seas_t_np_dnp(t,c,ibionp_13C_Corg_dia)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of umol opal cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_dia_opal_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_opal_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol Corg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_coc_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_Corg_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_coc_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (calc_d13C(seas_t_np_dnp(t,c,ibionp_Corg_coc),seas_t_np_dnp(t,c,ibionp_13C_Corg_coc)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol CaCO3 cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_coc_CaCO3_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_CaCO3_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol cal cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_coc_cal_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_cal_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_coc_d13CaCO3_cal.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (calc_d13C(seas_t_np_dnp(t,c,ibionp_cal_coc),seas_t_np_dnp(t,c,ibionp_13C_cal_coc)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol arg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_coc_arg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_arg_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_coc_d13CaCO3_arg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (calc_d13C(seas_t_np_dnp(t,c,ibionp_arg_coc),seas_t_np_dnp(t,c,ibionp_13C_arg_coc)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save total np data ***
! NOTE: in units of umol Corg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_tot_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_Corg_tot),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save total np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_tot_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (calc_d13C(seas_t_np_dnp(t,c,ibionp_Corg_tot),seas_t_np_dnp(t,c,ibionp_13C_Corg_tot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (opal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_tot_opaltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_opal_dia) / (1E-12 + seas_t_np_dnp(t,c,ibionp_Corg_tot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (Corg:Feorg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_tot_FeorgtoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.1)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_Corg_tot) / (1E-12 + seas_t_np_dnp(t,c,ibionp_Feorg_tot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (CaCO3:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_tot_CaCO3toCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_CaCO3_coc) / (1E-12 + seas_t_np_dnp(t,c,ibionp_Corg_tot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (cal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_tot_caltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_cal_coc) / (1E-12 + seas_t_np_dnp(t,c,ibionp_Corg_tot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (arg:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_tot_argtoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_arg_coc) / (1E-12 + seas_t_np_dnp(t,c,ibionp_Corg_tot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (opal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_dia_opaltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dnp(t,c,ibionp_opal_dia) / (1E-12 + seas_t_np_dnp(t,c,ibionp_Corg_dia)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom I kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kI_dia.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_I_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore I kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kI_coc.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_I_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom T kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kT_dia.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_T_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore T kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kT_coc.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_T_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom [PO4] kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kPO4_dia.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_PO4_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore [PO4] kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kPO4_coc.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_PO4_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom [H4SiO4] kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kSi_dia.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_Si_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore [H4SiO4] kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kSi_coc.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_Si_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom [Fe] kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kFe_dia.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_Fe_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore [Fe] kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_kFe_coc.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_Fe_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom total kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_ktot_dia.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_tot_dia),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore total kinetics data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_np_bionpxx_ktot_coc.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t = 1,(par_n_t_int * par_n_t_np)
      WRITE(unit=out,FMT='(F7.1,99F10.3)') &
	& t * 360.0 / REAL(par_n_t_int * par_n_t_np,KIND=fp_1), &
	& (seas_t_np_dk(t,c,ibiok_tot_coc),c=1,n_col)
    END DO
    CLOSE(unit=out)

  END SUBROUTINE save_seas_t_np_all
! *************************************************************


! ***********************************************************
! *** save integration time step seasonal misc state data ***
! ***********************************************************
  SUBROUTINE save_seas_t_int_misc(tsave)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::tsave
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=3)::tsave_string
    INTEGER::c
    INTEGER::t_int
    INTEGER::out = 1

! *** create filename identifier string ***
    IF (tsave <= 9) THEN
      WRITE(tsave_string(3:3),'(i1)')tsave
      tsave_string(1:2) = "00"
    ELSE IF (tsave <= 99) THEN
      WRITE(tsave_string(2:3),'(i2)')tsave
      tsave_string(1:1) = "0"
    ELSE
      WRITE(tsave_string(1:3),'(i3)')tsave
    ENDIF

! *** save insolation data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_misc_insol.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_insol(t_int,c),c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save seaice data ***
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_misc_seaice.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_seaice(t_int,c),c=1,n_col)
    END DO
    CLOSE(unit=out)

  END SUBROUTINE save_seas_t_int_misc
! ***********************************************************


! ********************************************************************
! *** save integration time step seasonal ocean surface state data ***
! ********************************************************************
  SUBROUTINE save_seas_t_int_surxx(tsave)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::tsave
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=3)::tsave_string
    INTEGER::c
    INTEGER::t_int
    INTEGER::out = 1
    REAL(KIND=fp_1)::depth = 0.0
    REAL(KIND=fp_1),DIMENSION(par_n_t_int,n_col,n_dis)::dis_const_box
    REAL(KIND=fp_1),DIMENSION(par_n_t_int,n_col)::fug_CO2,conc_CO2,conc_CO3,conc_HCO3
    REAL(KIND=fp_1),DIMENSION(par_n_t_int,n_col)::conc_Ca,ohm_cal,ohm_arg,dCO3_cal,dCO3_arg,pH

! *** create filename identifier string ***
    IF (tsave <= 9) THEN
      WRITE(tsave_string(3:3),'(i1)')tsave
      tsave_string(1:2) = "00"
    ELSE IF (tsave <= 99) THEN
      WRITE(tsave_string(2:3),'(i2)')tsave
      tsave_string(1:1) = "0"
    ELSE
      WRITE(tsave_string(1:3),'(i3)')tsave
    ENDIF

! *** calculate derived local tracer values ***
! calculate carbonate equilibrium constants
    DO c = 1,n_col
      DO t_int = 1,par_n_t_int
	CALL co2const_ex &
	  & ( &
	  &   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_T), &
	  &   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_S), &
	  &   depth, &
	  &   dis_const_box(t_int,c,:) &
	  & )
      END DO
    END DO
! calculate ocean surface carbonate equilibrium
    DO c = 1,n_col
      DO t_int = 1,par_n_t_int
	CALL calccarb_ex &
	  & ( &
	  &   dis_const_box(t_int,c,:), &
	  &   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_S), &
	  &   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_alk), &
	  &   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_CO2), &
	  &   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_PO4), &
	  &   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_Si), &
	  &   conc_Ca(t_int,c),fug_CO2(t_int,c),conc_CO2(t_int,c),conc_CO3(t_int,c),conc_HCO3(t_int,c), &
	  &   ohm_cal(t_int,c),ohm_arg(t_int,c),dCO3_cal(t_int,c),dCO3_arg(t_int,c),pH(t_int,c) &
	  & )
      ENDDO
    END DO

    
! *** save T data ***
! NOTE: in units of degrees kelvin
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_T.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_T),c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save salinity data ***
! NOTE: in units of o/oo
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_S.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_S),c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save density data ***
! NOTE: in units of (kg m-3)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_rho.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& (calc_rho &
	& ( &
	&   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_T), &
	&   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_S) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save [CO2] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_CO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_CO2)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save [alk] data ***
! NOTE: in units of umol eq kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_alk.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_alk)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save [PO4] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_PO4.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_PO4)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save [Si] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_Si.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_Si)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save [Fe] data ***
! NOTE: in units of nmol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_Fe.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_Fe)*1.0E9,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [O2] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_O2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_O2)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save [DOC] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_DOC.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_DOC)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save [DOFe] data ***
! NOTE: in units of nmol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_DOFe.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (seas_t_int_oatracer(t_int)%ioat_t(c,1,it_DOFe)*1.0E9,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save d13C data ***
! NOTE: in units of o/oo
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_d13C.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& (calc_d13C &
	& ( &
	&   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_CO2), &
	&   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_13C_CO2) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save d13C(DOC) data ***
! NOTE: in units of o/oo
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_d13C_DOC.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& (calc_d13C &
	& ( &
	&   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_DOC), &
	&   seas_t_int_oatracer(t_int)%ioat_t(c,1,it_13C_DOC) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [CO2] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_concCO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (conc_CO2(t_int,c) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)
    
! *** save [CO3] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_concCO3.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (conc_CO3(t_int,c) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)
    
! *** save [HCO3] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_concHCO3.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (conc_HCO3(t_int,c) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)
    
! *** save fCO2 data ***
! NOTE: in units of ppmv
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_fugCO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') (fug_CO2(t_int,c) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)
    
! *** save delta(pCO2) data ***
! NOTE: in units of ppmv
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_surxxxx_deltapCO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	& (fug_CO2(t_int,c) - seas_t_int_oatracer(t_int)%ioat_a(ia_pCO2)) * 1.0E+06 &
	& ,c=1,n_col)
    ENDDO
    CLOSE(unit=out)
    
  END SUBROUTINE save_seas_t_int_surxx
! ********************************************************************


! ***************************************************************
! *** save integration time step seasonal new production data ***
! ***************************************************************
  SUBROUTINE save_seas_t_int_bionpxx(tsave,phys)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::tsave
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::phys
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=3)::tsave_string
    INTEGER::c
    INTEGER::t_int
    INTEGER::out=1

! *** create filename identifier string ***
    IF (tsave <= 9) THEN
      WRITE(tsave_string(3:3),'(i1)')tsave
      tsave_string(1:2) = "00"
    ELSE IF (tsave <= 99) THEN
      WRITE(tsave_string(2:3),'(i2)')tsave
      tsave_string(1:1) = "0"
    ELSE
      WRITE(tsave_string(1:3),'(i3)')tsave
    ENDIF

! *** save diatom np data ***
! NOTE: in units of umol Corg cm-2 a-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_dia_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ((REAL(par_n_t_int,KIND=fp_1) * conv_mol_umol * seas_t_int_bionp(t_int,c,ibionp_Corg_dia)) / &
	& (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_dia_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   calc_d13C &
	&   ( &
	&     seas_t_int_bionp(t_int,c,ibionp_Corg_dia), &
	&     seas_t_int_bionp(t_int,c,ibionp_13C_Corg_dia) &
	&   ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of umol Si cm-2 a-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_dia_opal_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ((REAL(par_n_t_int,KIND=fp_1) * conv_mol_umol * seas_t_int_bionp(t_int,c,ibionp_opal_dia)) / &
	& (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save coccolithophore np data ***
! NOTE: in units of umol C cm-2 a-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_coc_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ((REAL(par_n_t_int,KIND=fp_1) * conv_mol_umol * seas_t_int_bionp(t_int,c,ibionp_Corg_coc)) / &
	& (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_coc_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   calc_d13C &
	&   ( &
	&     seas_t_int_bionp(t_int,c,ibionp_Corg_coc), &
	&     seas_t_int_bionp(t_int,c,ibionp_13C_Corg_coc) &
	&   ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol CaCO3 cm-2 a-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_coc_CaCO3_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ((REAL(par_n_t_int,KIND=fp_1) * conv_mol_umol * seas_t_int_bionp(t_int,c,ibionp_CaCO3_coc)) / &
	(conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol calcite cm-2 a-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_coc_cal_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ((REAL(par_n_t_int,KIND=fp_1) * conv_mol_umol * seas_t_int_bionp(t_int,c,ibionp_cal_coc)) / &
	(conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_coc_d13CaCO3_cal.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   calc_d13C &
	&   ( &
	&     seas_t_int_bionp(t_int,c,ibionp_cal_coc), &
	&     seas_t_int_bionp(t_int,c,ibionp_13C_cal_coc) &
	&   ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol aragonite cm-2 a-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_coc_arg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ((REAL(par_n_t_int,KIND=fp_1) * conv_mol_umol * seas_t_int_bionp(t_int,c,ibionp_arg_coc)) / &
	(conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    END DO
    CLOSE(unit=out)


! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_coc_d13CaCO3_arg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   calc_d13C &
	&   ( &
	&     seas_t_int_bionp(t_int,c,ibionp_arg_coc), &
	&     seas_t_int_bionp(t_int,c,ibionp_13C_arg_coc) &
	&   ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save total np data ***
! NOTE: in units of umol C cm-2 a-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_tot_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ((REAL(par_n_t_int,KIND=fp_1) * conv_mol_umol * seas_t_int_bionp(t_int,c,ibionp_Corg_tot)) / &
	(conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save total np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_tot_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   calc_d13C &
	&   ( &
	&     seas_t_int_bionp(t_int,c,ibionp_Corg_tot), &
	&     seas_t_int_bionp(t_int,c,ibionp_13C_Corg_tot) &
	&   ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (opal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_tot_opaltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   seas_t_int_bionp(t_int,c,ibionp_opal_dia) &
	&   / &
	&   (0.000001 + seas_t_int_bionp(t_int,c,ibionp_Corg_tot) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (Corg:Feorg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_tot_FeorgtoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.1)') &
	& ( &
	&   seas_t_int_bionp(t_int,c,ibionp_Corg_tot) &
	&   / &
	&   (0.000001 + seas_t_int_bionp(t_int,c,ibionp_Feorg_tot) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (CaCO3:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_tot_CaCO3toCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   seas_t_int_bionp(t_int,c,ibionp_CaCO3_coc) &
	&   / &
	&   (0.000001 + seas_t_int_bionp(t_int,c,ibionp_Corg_tot) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (cal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_tot_caltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   seas_t_int_bionp(t_int,c,ibionp_cal_coc) &
	&   / &
	&   (0.000001 + seas_t_int_bionp(t_int,c,ibionp_Corg_tot) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (arg:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_tot_argtoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   seas_t_int_bionp(t_int,c,ibionp_arg_coc) &
	&   / &
	&   (0.000001 + seas_t_int_bionp(t_int,c,ibionp_Corg_tot) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save np data (opal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_int_bionpxx_dia_opaltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO t_int = 1,par_n_t_int
      WRITE(unit=out,FMT='(99F10.3)') &
	& ( &
	&   seas_t_int_bionp(t_int,c,ibionp_opal_dia) &
	&   / &
	&   (0.000001 + seas_t_int_bionp(t_int,c,ibionp_Corg_dia) &
	& ) &
	& ,c=1,n_col)
    END DO
    CLOSE(unit=out)
    
  END SUBROUTINE save_seas_t_int_bionpxx
! ***************************************************************


! *********************************
! *** save ocean box state data ***
! *********************************
  SUBROUTINE save_boxxxxx(tsave,phys,oat,ocva)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::tsave
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::phys
    TYPE(ocean_atm_tracer),INTENT(in)::oat
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_t_int_max)::ocva
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=2)::col_num,lay_num
    CHARACTER(LEN=3)::tsave_string
    INTEGER::c,l
    INTEGER::out=1
    REAL(KIND=fp_1)::depth
    REAL(KIND=fp_1),DIMENSION(n_col,n_lay,n_dis)::dis_const_box
    REAL(KIND=fp_1),DIMENSION(n_col,n_lay)::fug_CO2,conc_CO2,conc_CO3,conc_HCO3
    REAL(KIND=fp_1),DIMENSION(n_col,n_lay)::conc_Ca,ohm_cal,ohm_arg,dCO3_cal,dCO3_arg,pH

! *** create filename identifier string ***
    IF (tsave <= 9) THEN
      WRITE(tsave_string(3:3),'(i1)')tsave
      tsave_string(1:2) = "00"
    ELSE IF (tsave <= 99) THEN
      WRITE(tsave_string(2:3),'(i2)')tsave
      tsave_string(1:1) = "0"
    ELSE
      WRITE(tsave_string(1:3),'(i3)')tsave
    ENDIF

! *** calculate derived local tracer values ***
! calculate carbonate equilibrium constants
    DO c = 1,n_col
      DO l = 1,n_lay
	depth = (phys(c,l,ip_D_top) + phys(c,l,ip_D_bot)) / 2.0
	CALL co2const_ex(phys(c,l,ip_T),oat%ioat_t(c,l,it_S),depth,dis_const_box(c,l,:))
      ENDDO
    END DO
! calculate ocean surface carbonate equilibrium
    DO c = 1,n_col
      DO l = 1,n_lay
	CALL calccarb_ex(dis_const_box(c,l,:),oat%ioat_t(c,l,it_S),oat%ioat_t(c,l,it_alk), &
	  & oat%ioat_t(c,l,it_CO2),oat%ioat_t(c,l,it_PO4),oat%ioat_t(c,l,it_Si), &
	  & conc_Ca(c,l),fug_CO2(c,l),conc_CO2(c,l),conc_CO3(c,l),conc_HCO3(c,l), &
	  & ohm_cal(c,l),ohm_arg(c,l),dCO3_cal(c,l),dCO3_arg(c,l),pH(c,l))
      ENDDO
    END DO

! *** save volume data ***
! NOTE: in units of (m3)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_V.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99E15.6)') (phys(c,l,ip_V),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save top surface area data ***
! NOTE: in units of (m2)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_A_top.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99E15.6)') (phys(c,l,ip_A_top),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save bottom surface area data ***
! NOTE: in units of (m2)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_A_bot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99E15.6)') (phys(c,l,ip_A_bot),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save layer thickness data ***
! NOTE: in units of (m)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_lay_th.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F9.3)') (phys(c,l,ip_D_bot) - phys(c,l,ip_D_top),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save layer top depth data ***
! NOTE: in units of (m)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_D_top.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (phys(c,l,ip_D_top),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save layer bottom depth data ***
! NOTE: in units of (m)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_D_bot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (phys(c,l,ip_D_bot),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save northern cross-sectional area data ***
! NOTE: in units of (m2)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_csA_N.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99E15.6)') (phys(c,l,ip_csA_N),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save southern cross-sectional area data ***
! NOTE: in units of (m2)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_csA_S.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99E15.6)') (phys(c,l,ip_csA_S),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save Corg remineralization profile data ***
! NOTE: in units of fraction of np remaining
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_remin_Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.6)') (phys(c,l,ip_reminf_Corg),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save opal remineralization profile data ***
! NOTE: in units of fraction of np remaining
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_remin_opal.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.6)') (phys(c,l,ip_reminf_opal),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save cal remineralization profile data ***
! NOTE: in units of fraction of np remaining
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_remin_cal.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.6)') (phys(c,l,ip_reminf_cal),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save arg remineralization profile data ***
! NOTE: in units of fraction of np remaining
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_remin_arg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.6)') (phys(c,l,ip_reminf_arg),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save mean ocean convective adjustment data ***
! NOTE: in units of (yr-1)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_ocva.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay - 1
      WRITE(unit=out,FMT='(99F10.3)') (SUM(ocva(c,l,:)) / n_t_int_max,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save T data ***
! NOTE: in units of degrees kelvin
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_T.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_T),c=1,n_col)
    END DO
    CLOSE(unit=out)
    
! *** save salinity data ***
! NOTE: in units of o/oo
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_S.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_S),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save density data ***
! NOTE: in units of (kg m-3)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_rho.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (calc_rho(oat%ioat_t(c,l,it_T),oat%ioat_t(c,l,it_S)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [CO2] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_CO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_CO2)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [alk] data ***
! NOTE: in units of umol eq kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_alk.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_alk)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [PO4] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_PO4.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_PO4)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [Si] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_Si.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_Si)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [Fe] data ***
! NOTE: in units of nmol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_Fe.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_Fe)*1.0E9,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [Fe'] data ***
! NOTE: in units of pmol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_Feprime.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (par_conv_Fe_tot_inorg * oat%ioat_t(c,l,it_Fe)*1.0E12,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [O2] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_O2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_O2)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [DOC] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_DOC.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_DOC)*1.0E6,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [DOFe] data ***
! NOTE: in units of nmol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_DOFe.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (oat%ioat_t(c,l,it_DOFe)*1.0E9,c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save d13C data ***
! NOTE: in units of o/oo
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_d13C.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') &
	& (calc_d13C(oat%ioat_t(c,l,it_CO2),oat%ioat_t(c,l,it_13C_CO2)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save d13C(DOC) data ***
! NOTE: in units of o/oo
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_d13C_DOC.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') &
	& (calc_d13C(oat%ioat_t(c,l,it_DOC),oat%ioat_t(c,l,it_13C_DOC)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save d18O data ***
! NOTE: in units of o/oo
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_d18O.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') &
	& (calc_d18O(oat%ioat_t(c,l,it_O2),oat%ioat_t(c,l,it_18O_O2)),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save D_calsat data ***
! NOTE: in units of m
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_Dcalsat.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (phys(c,l,ip_D_calsat),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save D_argsat data ***
! NOTE: in units of m
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_Dargsat.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (phys(c,l,ip_D_argsat),c=1,n_col)
    END DO
    CLOSE(unit=out)

! *** save [CO2] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_concCO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (conc_CO2(c,l) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)

! *** save [CO3] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_concCO3.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (conc_CO3(c,l) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)

! *** save [HCO3] data ***
! NOTE: in units of umol kg-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_concHCO3.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (conc_HCO3(c,l) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)

! *** save fCO2 data ***
! NOTE: in units of ppmv
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_fugCO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') (fug_CO2(c,l) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)

! *** save delta(pCO2) data ***
! NOTE: in units of ppmv
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_boxxxxx_deltapCO2.res"
    OPEN(unit=out,file=filename,action="WRITE")
    DO l = 1,n_lay
      WRITE(unit=out,FMT='(99F10.3)') ((fug_CO2(c,l) - oat%ioat_a(ia_pCO2)) * 1.0E+06,c=1,n_col)
    ENDDO
    CLOSE(unit=out)

  END SUBROUTINE save_boxxxxx
! *********************************


! **********************************
! *** save surface np state data ***
! **********************************
  SUBROUTINE save_bionpxx(tsave,phys,np)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::tsave
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::phys
    REAL(KIND=fp_1),DIMENSION(n_col,n_bionp),INTENT(in)::np
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=2)::col_num,lay_num
    CHARACTER(LEN=3)::tsave_string
    INTEGER::c,l
    INTEGER::out=1

! *** create filename identifier string ***
    IF (tsave <= 9) THEN
      WRITE(tsave_string(3:3),'(i1)')tsave
      tsave_string(1:2) = "00"
    ELSE IF (tsave <= 99) THEN
      WRITE(tsave_string(2:3),'(i2)')tsave
      tsave_string(1:1) = "0"
    ELSE
      WRITE(tsave_string(1:3),'(i3)')tsave
    ENDIF

! *** save diatom np data ***
! NOTE: in units of mol C yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_dia_Corg_tot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99E10.3)') &
      & (np(c,ibionp_Corg_dia),c=1,n_col)
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of umol Corg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_dia_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (conv_mol_umol * np(c,ibionp_Corg_dia) / (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_dia_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (calc_d13C(np(c,ibionp_Corg_dia),np(c,ibionp_13C_Corg_dia)),c=1,n_col)
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of mol Si yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_dia_opal_tot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99E10.3)') &
      & (np(c,ibionp_opal_dia),c=1,n_col)
    CLOSE(unit=out)

! *** save diatom np data ***
! NOTE: in units of umol opal cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_dia_opal_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (conv_mol_umol * np(c,ibionp_opal_dia) / (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    CLOSE(unit=out)
    
! *** save coccolithophore np data ***
! NOTE: in units of mol C yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_Corg_tot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99E10.3)') &
      & (np(c,ibionp_Corg_coc),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol Corg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (conv_mol_umol * np(c,ibionp_Corg_coc) / (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (calc_d13C(np(c,ibionp_Corg_coc),np(c,ibionp_13C_Corg_coc)),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of mol CaCO3 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_CaCO3_tot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99E10.3)') &
      & (np(c,ibionp_CaCO3_coc),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol CaCO3 cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_CaCO3_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (conv_mol_umol * np(c,ibionp_CaCO3_coc) / (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of mol calcite yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_cal_tot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99E10.3)') &
      & (np(c,ibionp_cal_coc),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol cal cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_cal_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (conv_mol_umol * np(c,ibionp_cal_coc) / (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_d13CaCO3_cal.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (calc_d13C(np(c,ibionp_cal_coc),np(c,ibionp_13C_cal_coc)),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of mol aragonite yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_arg_tot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99E10.3)') &
      & (np(c,ibionp_arg_coc),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of umol arg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_arg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (conv_mol_umol * np(c,ibionp_arg_coc) / (conv_m2_cm2 * phys(c,1,ip_A_bot)),c=1,n_col)
    CLOSE(unit=out)

! *** save coccolithophore np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_coc_d13CaCO3_arg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (calc_d13C(np(c,ibionp_arg_coc),np(c,ibionp_13C_arg_coc)),c=1,n_col)
    CLOSE(unit=out)

! *** save total np data ***
! NOTE: in units of mol C yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_Corg_tot.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99E10.3)') &
      & (np(c,ibionp_Corg_tot),c=1,n_col)
    CLOSE(unit=out)

! *** save total np data ***
! NOTE: in units of umol Corg cm-2 yr-1
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_Corg_den.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & ((np(c,ibionp_Corg_dia) + np(c,ibionp_Corg_coc)) * conv_mol_umol &
      & / (phys(c,1,ip_A_bot) * conv_m2_cm2),c=1,n_col)
    CLOSE(unit=out)

! *** save total np data ***
! NOTE: in units of (o/oo)
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_d13Corg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (calc_d13C(np(c,ibionp_Corg_tot),np(c,ibionp_13C_Corg_tot)),c=1,n_col)
    CLOSE(unit=out)

! *** save np data (opal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_opaltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (np(c,ibionp_opal_dia) / (0.000001 + np(c,ibionp_Corg_tot)),c=1,n_col)
    CLOSE(unit=out)

! *** save np data (Corg:Feorg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_FeorgtoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.1)') &
      & (np(c,ibionp_Corg_tot) / (0.000001 + np(c,ibionp_Feorg_tot)),c=1,n_col)
    CLOSE(unit=out)

! *** save np data (CaCO3:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_CaCO3toCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') ( &
      & np(c,ibionp_CaCO3_coc) / (0.000001 + np(c,ibionp_Corg_tot)),c=1,n_col)
    CLOSE(unit=out)

! *** save np data (cal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_caltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') ( &
      & np(c,ibionp_cal_coc) / (0.000001 + np(c,ibionp_Corg_tot)),c=1,n_col)
    CLOSE(unit=out)

! *** save np data (arg:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_tot_argtoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') ( &
      & np(c,ibionp_arg_coc) / (0.000001 + np(c,ibionp_Corg_tot)),c=1,n_col)
    CLOSE(unit=out)

! *** save np data (opal:Corg) ***
! NOTE: in units of a dimensionless ratio
    filename = modelname//"_output/"//modelname//"_"//tsave_string//"kaBP_t_ann_bionpxx_dia_opaltoCorg.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(99F10.3)') &
      & (np(c,ibionp_opal_dia) / (0.000001 + np(c,ibionp_Corg_dia)),c=1,n_col)
    CLOSE(unit=out)

  END SUBROUTINE save_bionpxx
! *********************************


! ************************************************
! *** save (kyr) box (tracer and physics) data ***
! ************************************************
  SUBROUTINE save_kyr_box_data(ticeinit,kphys,koat,kocv,sphys,soat,socv)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::ticeinit
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_lay,1:n_phys_kyr)::kphys
    TYPE(ocean_atm_tracer),INTENT(in),DIMENSION(0:n_kyr)::koat
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_lay,n_t_int_max)::kocv
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_lay,1:n_phys_spin)::sphys
    TYPE(ocean_atm_tracer),INTENT(in),DIMENSION(n_spin)::soat
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_lay,n_t_int_max)::socv
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=2)::col_num,lay_num
    INTEGER::c=0,l=0,n=0,out=1,t=0
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::k_tot_M
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::s_tot_M
    REAL(KIND=fp_1),DIMENSION(n_dis)::dis
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::k_fug_CO2,k_conc_CO2,k_conc_CO3,k_conc_HCO3
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::k_conc_Ca,k_ohm_cal,k_ohm_arg,k_dCO3_cal,k_dCO3_arg,k_pH
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::s_fug_CO2,s_conc_CO2,s_conc_CO3,s_conc_HCO3
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::s_conc_Ca,s_ohm_cal,s_ohm_arg,s_dCO3_cal,s_dCO3_arg,s_pH

!   INDEX   PARAMETER   (UNITS)
!     
!   00      time        (kyr BP)
!   01      box volume  (m3)
!   02      conv adj    (yr-1)
!   03      temperature (K)
!   04      salinity    (o/oo)
!   05      rho         (kg m-3)
!   06      [alk]       (mol Eq kg-1))
!   07      [SUM(CO2)]  (mol kg-1)
!   08      [PO4]       (mol kg-1)
!   09      [Si]        (mol kg-1)
!   10      [Fe]        (nmol kg-1)
!   11      [O2]        (atm)
!   12      d13C(CO2)   (o/oo)
!   13      d18O(O2)    (o/oo)
!   14      fCO2        (ppmv)
!   15      [CO2]       (mol kg-1)
!   16      [CO3]       (mol kg-1)
!   17      [HCO3]      (mol kg-1)
!   18      ohm_cal     ()
!   19      ohm_arg     ()
!   20      dCO3_cal    (mol kg-1)
!   21      dCO3_arg    (mol kg-1)
!   22      D_calsat    (m)
!   23      D_argsat    (m)
!   24      pH          (pH units)


! *** save ocean box data ***

! *** column and layer loops ***
    DO c = 1,n_col
      col_num = conv_num_char(c)
      DO l = 1,n_lay
	lay_num = conv_num_char(l)
	
! *** calculate ocean pH ***
! glacial-interglacial cycle carbonate chemistry data
	DO t = 0,t_ice_init,1
	  CALL co2const_ex(koat(t)%ioat_t(c,l,it_T),koat(t)%ioat_t(c,l,it_S), &
	    & (kphys(t,c,l,ip_D_top) + kphys(t,c,l,ip_D_top)) / 2.0,dis)
	  CALL calccarb_ex(dis,koat(t)%ioat_t(c,l,it_S),koat(t)%ioat_t(c,l,it_alk), &
	  & koat(t)%ioat_t(c,l,it_CO2),koat(t)%ioat_t(c,l,it_PO4),koat(t)%ioat_t(c,l,it_Si), &
	  & k_conc_Ca(t),k_fug_CO2(t),k_conc_CO2(t),k_conc_CO3(t),k_conc_HCO3(t), &
	  & k_ohm_cal(t),k_ohm_arg(t),k_dCO3_cal(t),k_dCO3_arg(t),k_pH(t))
	END DO
! spin-up cycle carbonate chemistry data
	DO t = t_spin_max,1,-1
	  CALL co2const_ex(soat(t)%ioat_t(c,l,it_T),soat(t)%ioat_t(c,l,it_S), &
	    & (sphys(t,c,l,ip_D_top) + sphys(t,c,l,ip_D_top)) / 2.0,dis)
	  CALL calccarb_ex(dis,soat(t)%ioat_t(c,l,it_S),soat(t)%ioat_t(c,l,it_alk), &
	  & soat(t)%ioat_t(c,l,it_CO2),soat(t)%ioat_t(c,l,it_PO4),soat(t)%ioat_t(c,l,it_Si), &
	  & s_conc_Ca(t),s_fug_CO2(t),s_conc_CO2(t),s_conc_CO3(t),s_conc_HCO3(t), &
	  & s_ohm_cal(t),s_ohm_arg(t),s_dCO3_cal(t),s_dCO3_arg(t),s_pH(t))
	END DO

! *** save individual cell kyr data ***
! NOTE: alk, [CO2], [PO4], [Si], [O2] are in units of umol kg-1, [Fe] is in units of nmol kg-1
! set filename
	filename = modelname//"_output/"//modelname//"_kyr_box"//col_num//lay_num//".res"
! open file pipe
	OPEN(unit=out,file=filename,action="write")
! save glacial-interglacial cycle data
	DO t = 0,t_ice_init,1
	  WRITE(unit=out,FMT='(I4,24E14.6)') t,                                     &
	    & kphys(t,c,l,ip_V),                                                    &
	    & SUM(kocv(t,c,l,:)) / n_t_int_max,                                     &
	    & koat(t)%ioat_t(c,l,it_T),                                             & 
	    & koat(t)%ioat_t(c,l,it_S),                                             & 
	    & calc_rho(koat(t)%ioat_t(c,l,it_T),koat(t)%ioat_t(c,l,it_S)),          &
	    & koat(t)%ioat_t(c,l,it_alk) * 1.0E+06,                                 &
	    & koat(t)%ioat_t(c,l,it_CO2) * 1.0E+06,                                 &
	    & koat(t)%ioat_t(c,l,it_PO4) * 1.0E+06,                                 &
	    & koat(t)%ioat_t(c,l,it_Si)  * 1.0E+06,                                 &
	    & koat(t)%ioat_t(c,l,it_Fe)  * 1.0E+09,                                 &
	    & koat(t)%ioat_t(c,l,it_O2)  * 1.0E+06,                                 &
	    & calc_d13C(koat(t)%ioat_t(c,l,it_CO2),koat(t)%ioat_t(c,l,it_13C_CO2)), &
	    & calc_d18O(koat(t)%ioat_t(c,l,it_O2),koat(t)%ioat_t(c,l,it_18O_O2)),   &
	    & k_fug_CO2(t)               * 1.0E+06,                                 &
	    & k_conc_CO2(t)              * 1.0E+06,                                 &
	    & k_conc_CO3(t)              * 1.0E+06,                                 &
	    & k_conc_HCO3(t)             * 1.0E+06,                                 &
	    & k_ohm_cal(t),                                                         &
	    & k_ohm_arg(t),                                                         &
	    & k_dCO3_cal(t)              * 1.0E+06,                                 &
	    & k_dCO3_arg(t)              * 1.0E+06,                                 &
	    & kphys(t,c,l,ip_D_calsat),                                             &
	    & kphys(t,c,l,ip_D_argsat),                                             &
	    & k_pH(t)
	END DO
! save spin-up data
	DO t = t_spin_max,1,-1
	  WRITE(unit=out,FMT='(I4,24E14.6)') (t_spin_max - t + 1) + t_ice_init,     &
	    & sphys(t,c,l,ip_V),                                                    &
	    & SUM(socv(t,c,l,:)) / n_t_int_max,                                     &
	    & soat(t)%ioat_t(c,l,it_T),                                             & 
	    & soat(t)%ioat_t(c,l,it_S),                                             & 
	    & calc_rho(soat(t)%ioat_t(c,l,it_T),soat(t)%ioat_t(c,l,it_S)),          &
	    & soat(t)%ioat_t(c,l,it_alk) * 1.0E+06,                                 &
	    & soat(t)%ioat_t(c,l,it_CO2) * 1.0E+06,                                 &
	    & soat(t)%ioat_t(c,l,it_PO4) * 1.0E+06,                                 &
	    & soat(t)%ioat_t(c,l,it_Si)  * 1.0E+06,                                 &
	    & soat(t)%ioat_t(c,l,it_Fe)  * 1.0E+09,                                 &
	    & soat(t)%ioat_t(c,l,it_O2)  * 1.0E+06,                                 &
	    & calc_d13C(soat(t)%ioat_t(c,l,it_CO2),soat(t)%ioat_t(c,l,it_13C_CO2)), &
	    & calc_d18O(soat(t)%ioat_t(c,l,it_O2),soat(t)%ioat_t(c,l,it_18O_O2)),   &
	    & s_fug_CO2(t)               * 1.0E+06,                                 &
	    & s_conc_CO2(t)              * 1.0E+06,                                 &
	    & s_conc_CO3(t)              * 1.0E+06,                                 &
	    & s_conc_HCO3(t)             * 1.0E+06,                                 &
	    & s_ohm_cal(t),                                                         &
	    & s_ohm_arg(t),                                                         &
	    & s_dCO3_cal(t)              * 1.0E+06,                                 &
	    & s_dCO3_arg(t)              * 1.0E+06,                                 &
	    & sphys(t,c,l,ip_D_calsat),                                             &
	    & sphys(t,c,l,ip_D_argsat),                                             &
	    & s_pH(t)
	END DO
	CLOSE(unit=out)
	
      END DO
    END DO


  END SUBROUTINE save_kyr_box_data
! ************************************************


! *******************************************************
! *** save global (kyr) box (tracer and physics) data ***
! *******************************************************
  SUBROUTINE save_kyr_box_data_global(ticeinit,kphys,koat,kocv,sphys,soat,socv)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::ticeinit
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_lay,1:n_phys_kyr)::kphys
    TYPE(ocean_atm_tracer),INTENT(in),DIMENSION(0:n_kyr)::koat
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_lay,n_t_int_max)::kocv
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_lay,1:n_phys_spin)::sphys
    TYPE(ocean_atm_tracer),INTENT(in),DIMENSION(n_spin)::soat
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_lay,n_t_int_max)::socv
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=2)::col_num,lay_num
    INTEGER::c=0,l=0,n=0,out=1,t=0
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::k_tot_M
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::s_tot_M
    REAL(KIND=fp_1),DIMENSION(n_dis)::dis
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::k_fug_CO2,k_conc_CO2,k_conc_CO3,k_conc_HCO3
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::k_conc_Ca,k_ohm_cal,k_ohm_arg,k_dCO3_cal,k_dCO3_arg,k_pH
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::s_fug_CO2,s_conc_CO2,s_conc_CO3,s_conc_HCO3
    REAL(KIND=fp_1),DIMENSION(0:n_kyr)::s_conc_Ca,s_ohm_cal,s_ohm_arg,s_dCO3_cal,s_dCO3_arg,s_pH


! *** save whole ocean data ***

! *** save data ***
! NOTE: alk, [CO2], [PO4], [Si], [O2] are in units of umol kg-1, [Fe] is in units of nmol kg-1
! calculate total ocean mass
    DO t = 0,t_ice_init,1
      k_tot_M(t) = SUM(kphys(t,:,:,ip_M))
    END DO
    DO t = t_spin_max,1,-1
      s_tot_M(t) = SUM(sphys(t,:,:,ip_M))
    END DO
! set filename
    filename = modelname//"_output/"//modelname//"_kyr_ocean.res"
! open file pipe
    OPEN(unit=out,file=filename,action="WRITE")
! save glacial-interglacial cycle whole ocean data
    DO t = 0,t_ice_init,1
      WRITE(unit=out,FMT='(I4,22E14.6)') t, &
	& 1.0E6 * SUM(koat(t)%ioat_t(:,:,it_CO2)  * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E6 * SUM(koat(t)%ioat_t(:,:,it_alk)  * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E6 * SUM(koat(t)%ioat_t(:,:,it_PO4)  * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E6 * SUM(koat(t)%ioat_t(:,:,it_Si)   * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E6 * SUM(koat(t)%ioat_t(:,:,it_O2)   * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E9 * SUM(koat(t)%ioat_t(:,:,it_Fe)   * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E6 * SUM(koat(t)%ioat_t(:,:,it_DOC)  * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E9 * SUM(koat(t)%ioat_t(:,:,it_DOFe) * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E0 * SUM(koat(t)%ioat_t(:,:,it_T)    * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& 1.0E0 * SUM(koat(t)%ioat_t(:,:,it_S)    * kphys(t,:,:,ip_M)) / k_tot_M(t), &
	& calc_d13C                                                                &
	& (                                                                        &
	&   (SUM(koat(t)%ioat_t(:,:,it_CO2) * kphys(t,:,:,ip_M)) / k_tot_M(t)),    &
	&   (SUM(koat(t)%ioat_t(:,:,it_13C_CO2) * kphys(t,:,:,ip_M)) / k_tot_M(t)) &
	& )                                                                        &
	& , &
	& calc_d18O                                                               &
	& (                                                                       &
	&   (SUM(koat(t)%ioat_t(:,:,it_O2) * kphys(t,:,:,ip_M)) / k_tot_M(t)),    &
	&   (SUM(koat(t)%ioat_t(:,:,it_18O_O2) * kphys(t,:,:,ip_M)) / k_tot_M(t)) &
	& ), &
	& SUM(koat(t)%ioat_t(:,:,it_CO2)  * kphys(t,:,:,ip_M)), &
	& SUM(koat(t)%ioat_t(:,:,it_alk)  * kphys(t,:,:,ip_M)), &
	& SUM(koat(t)%ioat_t(:,:,it_PO4)  * kphys(t,:,:,ip_M)), &
	& SUM(koat(t)%ioat_t(:,:,it_Si)   * kphys(t,:,:,ip_M)), &
	& SUM(koat(t)%ioat_t(:,:,it_O2)   * kphys(t,:,:,ip_M)), &
	& SUM(koat(t)%ioat_t(:,:,it_Fe)   * kphys(t,:,:,ip_M)), &
	& SUM(koat(t)%ioat_t(:,:,it_DOC)  * kphys(t,:,:,ip_M)), &
	& SUM(koat(t)%ioat_t(:,:,it_DOFe) * kphys(t,:,:,ip_M)), &
	& SUM(kphys(t,:,:,ip_V)), &
	& SUM(kphys(t,:,:,ip_M))
    END DO
! save spin-up data
    DO t = t_spin_max,1,-1
      WRITE(unit=out,FMT='(I4,22E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	& 1.0E6 * SUM(soat(t)%ioat_t(:,:,it_CO2)  * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E6 * SUM(soat(t)%ioat_t(:,:,it_alk)  * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E6 * SUM(soat(t)%ioat_t(:,:,it_PO4)  * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E6 * SUM(soat(t)%ioat_t(:,:,it_Si)   * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E6 * SUM(soat(t)%ioat_t(:,:,it_O2)   * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E9 * SUM(soat(t)%ioat_t(:,:,it_Fe)   * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E6 * SUM(soat(t)%ioat_t(:,:,it_DOC)  * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E9 * SUM(soat(t)%ioat_t(:,:,it_DOFe) * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E0 * SUM(soat(t)%ioat_t(:,:,it_T)    * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& 1.0E0 * SUM(soat(t)%ioat_t(:,:,it_S)    * sphys(t,:,:,ip_M)) / s_tot_M(t), &
	& calc_d13C                                                                &
	& (                                                                        &
	&   (SUM(soat(t)%ioat_t(:,:,it_CO2) * sphys(t,:,:,ip_M)) / s_tot_M(t)),    &
	&   (SUM(soat(t)%ioat_t(:,:,it_13C_CO2) * sphys(t,:,:,ip_M)) / s_tot_M(t)) &
	& )                                                                        &
	& , &
	& calc_d18O                                                               &
	& (                                                                       &
	&   (SUM(soat(t)%ioat_t(:,:,it_O2) * sphys(t,:,:,ip_M)) / s_tot_M(t)),    &
	&   (SUM(soat(t)%ioat_t(:,:,it_18O_O2) * sphys(t,:,:,ip_M)) / s_tot_M(t)) &
	& ), &
	& SUM(soat(t)%ioat_t(:,:,it_CO2)  * sphys(t,:,:,ip_M)), &
	& SUM(soat(t)%ioat_t(:,:,it_alk)  * sphys(t,:,:,ip_M)), &
	& SUM(soat(t)%ioat_t(:,:,it_PO4)  * sphys(t,:,:,ip_M)), &
	& SUM(soat(t)%ioat_t(:,:,it_Si)   * sphys(t,:,:,ip_M)), &
	& SUM(soat(t)%ioat_t(:,:,it_O2)   * sphys(t,:,:,ip_M)), &
	& SUM(soat(t)%ioat_t(:,:,it_Fe)   * sphys(t,:,:,ip_M)), &
	& SUM(soat(t)%ioat_t(:,:,it_DOC)  * sphys(t,:,:,ip_M)), &
	& SUM(soat(t)%ioat_t(:,:,it_DOFe) * sphys(t,:,:,ip_M)), &
	& SUM(sphys(t,:,:,ip_V)), &
	& SUM(sphys(t,:,:,ip_M))
    END DO
! close file
    CLOSE(unit=out)


! *** save atmosphere data ***

! *** save data ***
! NOTE: pCO2 is in units of uatm
! set filename
    filename = modelname//"_output/"//modelname//"_kyr_atmosphere.res"
! open file pipe
    OPEN(unit=out,file=filename,action="WRITE")
! save glacial-interglacial cycle atmosphere data
    DO t = 0,t_ice_init,1
      WRITE(unit=out,FMT='(I4,F12.3,F10.3,F12.3,F10.3)') t, &
	& koat(t)%ioat_a(ia_pCO2) * 1.0E+06, &
	& calc_d13C(koat(t)%ioat_a(ia_pCO2),koat(t)%ioat_a(ia_13C_pCO2)), &
	& koat(t)%ioat_a(ia_pO2) * 1.0E+06, &
	& calc_d18O(koat(t)%ioat_a(ia_pO2),koat(t)%ioat_a(ia_18O_pO2))
    END DO
! save spin-up data
    DO t = t_spin_max,1,-1
      WRITE(unit=out,FMT='(I4,F12.3,F10.3,F12.3,F10.3)') (t_spin_max - t + 1) + t_ice_init, &
	& soat(t)%ioat_a(ia_pCO2) * 1.0E+06, &
	& calc_d13C(soat(t)%ioat_a(ia_pCO2),soat(t)%ioat_a(ia_13C_pCO2)), &
	& soat(t)%ioat_a(ia_pO2) * 1.0E+06, &
	& calc_d18O(soat(t)%ioat_a(ia_pO2),soat(t)%ioat_a(ia_18O_pO2))
    END DO
! close file
    CLOSE(unit=out)


! *** save convective adjustment data ***
! set filename
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_ocva_final.res"
! open file pipe
    OPEN(unit=out,file=filename,action="write")
! save final convective adjustment data
    DO t = 1,par_n_t_int
      DO l = 1, n_lay - 1
	WRITE(unit=out,FMT='(99F10.3)') (kocv(0,c,l,t),c=1,n_col)
      END DO
    END DO
    WRITE(unit=out,FMT='(A27)') "------- END OF DATA -------"
! close file pipe
    CLOSE(unit=out)

  END SUBROUTINE save_kyr_box_data_global
! *******************************************************


! *************************************************
! *** save (kyr) biological new production data ***
! *************************************************
  SUBROUTINE save_kyr_bionp_data(ticeinit,kyrphys,kyrbionp,spinphys,spinbionp)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::ticeinit
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_lay,1:n_phys_kyr)::kyrphys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_bionp)::kyrbionp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_lay,1:n_phys_spin)::spinphys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_bionp)::spinbionp
! local variables
    REAL(KIND=fp_1),DIMENSION(n_col,n_bionp)::bionp_tot
    REAL(KIND=fp_1),DIMENSION(n_col,n_bionp)::bionp_mean
    REAL(KIND=fp_1),DIMENSION(n_col,n_bionp)::bionp_final
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_Corg_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_Corg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_cal_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_arg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_opal_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_Feorg_tot
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_Corg_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_Corg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_cal_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_arg_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_DOC_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_DOC_coc
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_DOFe_tot
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_DOC_dia
    REAL(KIND=fp_1),DIMENSION(n_col)::bionp_d13C_DOC_coc
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=2)::col_num,lay_num
    INTEGER::c,t
    INTEGER::out=1
    INTEGER,DIMENSION(n_col)::t_tot

!   INDEX   PARAMETER                 (UNITS)
!     
!   00      time                      (kyr BP)
!   01      diatom Corg               (umol C cm-2 yr-1)
!   02      diatom opal               (umol Si cm-2 yr-1)
!   03      coccolithophore Corg      (umol C cm-2 yr-1)
!   04      coccolithophore CaCO3     (umol C cm-2 yr-1)
!   05      coccolithophore cal       (umol C cm-2 yr-1)
!   06      coccolithophore arg       (umol C cm-2 yr-1)
!   07      total Corg                (umol C cm-2 yr-1)
!   08      total Corg:Feorg          (n/a)
!   09      diatom opal:Corg          (n/a)
!   10      total CaCO3:Corg          (n/a)
!   11      total cal:Corg            (n/a)
!   12      total arg:Corg            (n/a)
!   13      diatom d13Corg            (o/oo)
!   14      coccolithophore d13Corg   (o/oo)
!   15      total d13Corg             (o/oo)
!   16      coccolithophore d13C cal  (o/oo)
!   17      coccolithophore d13C arg  (o/oo)


! *** initialize routine ***
! zero local variables
    bionp_tot   = 0.0
    bionp_mean  = 0.0
    bionp_final = 0.0
    t_tot       = 0


! *** kyr ocean grid point np data ***
    
    DO c = 1,n_col
      col_num = conv_num_char(c)
      
! *** save data ***
! set filename
      filename = modelname//"_output/"//modelname//"_kyr_bionp"//col_num//"xx.res"
! open file pipe
      OPEN(unit=out,file=filename,action="write")
! save glacial-interglacial cycle data
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,7F10.3,F14.3,4F10.3,3F9.3,2F7.3)') t,                                 &
	  & kyrbionp(t,c,ibionp_Corg_dia)  * conv_mol_umol / (kyrphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & kyrbionp(t,c,ibionp_opal_dia)  * conv_mol_umol / (kyrphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & kyrbionp(t,c,ibionp_Corg_coc)  * conv_mol_umol / (kyrphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & kyrbionp(t,c,ibionp_CaCO3_coc) * conv_mol_umol / (kyrphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & kyrbionp(t,c,ibionp_cal_coc)   * conv_mol_umol / (kyrphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & kyrbionp(t,c,ibionp_arg_coc)   * conv_mol_umol / (kyrphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & kyrbionp(t,c,ibionp_Corg_tot)  * conv_mol_umol / (kyrphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & kyrbionp(t,c,ibionp_Corg_tot)  / (kyrbionp(t,c,ibionp_Feorg_tot) + 0.000001),             &
	  & kyrbionp(t,c,ibionp_opal_dia)  / (kyrbionp(t,c,ibionp_Corg_dia)  + 0.000001),             &
	  & kyrbionp(t,c,ibionp_CaCO3_coc) / (kyrbionp(t,c,ibionp_Corg_tot)  + 0.000001),             &
	  & kyrbionp(t,c,ibionp_cal_coc)   / (kyrbionp(t,c,ibionp_Corg_tot)  + 0.000001),             &
	  & kyrbionp(t,c,ibionp_arg_coc)   / (kyrbionp(t,c,ibionp_Corg_tot)  + 0.000001),             &
	  & calc_d13C(kyrbionp(t,c,ibionp_Corg_dia),kyrbionp(t,c,ibionp_13C_Corg_dia)),               &
	  & calc_d13C(kyrbionp(t,c,ibionp_Corg_coc),kyrbionp(t,c,ibionp_13C_Corg_coc)),               &
	  & calc_d13C(kyrbionp(t,c,ibionp_Corg_tot),kyrbionp(t,c,ibionp_13C_Corg_tot)),               &
	  & calc_d13C(kyrbionp(t,c,ibionp_cal_coc),kyrbionp(t,c,ibionp_13C_cal_coc)),                 &
	  & calc_d13C(kyrbionp(t,c,ibionp_arg_coc),kyrbionp(t,c,ibionp_13C_arg_coc))
      END DO
! save spin-up data
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,7F10.3,F14.3,4F10.3,3F9.3,2F7.3)') (t_spin_max - t + 1) + t_ice_init,   &
	  & spinbionp(t,c,ibionp_Corg_dia)  * conv_mol_umol / (spinphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & spinbionp(t,c,ibionp_opal_dia)  * conv_mol_umol / (spinphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & spinbionp(t,c,ibionp_Corg_coc)  * conv_mol_umol / (spinphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & spinbionp(t,c,ibionp_CaCO3_coc) * conv_mol_umol / (spinphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & spinbionp(t,c,ibionp_cal_coc)   * conv_mol_umol / (spinphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & spinbionp(t,c,ibionp_arg_coc)   * conv_mol_umol / (spinphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & spinbionp(t,c,ibionp_Corg_tot)  * conv_mol_umol / (spinphys(t,c,1,ip_A_bot) * conv_m2_cm2), &
	  & spinbionp(t,c,ibionp_Corg_tot)  / (spinbionp(t,c,ibionp_Feorg_tot) + 0.000001),             &
	  & spinbionp(t,c,ibionp_opal_dia)  / (spinbionp(t,c,ibionp_Corg_dia)  + 0.000001),             &
	  & spinbionp(t,c,ibionp_CaCO3_coc) / (spinbionp(t,c,ibionp_Corg_tot)  + 0.000001),             &
	  & spinbionp(t,c,ibionp_cal_coc)   / (spinbionp(t,c,ibionp_Corg_tot)  + 0.000001),             &
	  & spinbionp(t,c,ibionp_arg_coc)   / (spinbionp(t,c,ibionp_Corg_tot)  + 0.000001),             &
	  & calc_d13C(spinbionp(t,c,ibionp_Corg_dia),spinbionp(t,c,ibionp_13C_Corg_dia)),               &
	  & calc_d13C(spinbionp(t,c,ibionp_Corg_coc),spinbionp(t,c,ibionp_13C_Corg_coc)),               &
	  & calc_d13C(spinbionp(t,c,ibionp_Corg_tot),spinbionp(t,c,ibionp_13C_Corg_tot)),               &
	  & calc_d13C(spinbionp(t,c,ibionp_cal_coc),spinbionp(t,c,ibionp_13C_cal_coc)),                 &
	  & calc_d13C(spinbionp(t,c,ibionp_arg_coc),spinbionp(t,c,ibionp_13C_arg_coc))
      END DO
      CLOSE(unit=out)
      
    END DO


! *** kyr ocean total np data ***
      
! *** save data ***
! set filename
    filename = modelname//"_output/"//modelname//"_kyr_bionp_ocean.res"
! open file pipe
    OPEN(unit=out,file=filename,action="write")
! save glacial-interglacial cycle data
    DO t = 0,t_ice_init,1
      WRITE(unit=out,FMT='(I4,7E10.3,F14.3,4F10.3,3F9.3,2F7.3)') t,                               &
	& SUM(kyrbionp(t,:,ibionp_Corg_dia)),                                                     &
	& SUM(kyrbionp(t,:,ibionp_opal_dia)),                                                     &
	& SUM(kyrbionp(t,:,ibionp_Corg_coc)),                                                     &
	& SUM(kyrbionp(t,:,ibionp_CaCO3_coc)),                                                    &
	& SUM(kyrbionp(t,:,ibionp_cal_coc)),                                                      &
	& SUM(kyrbionp(t,:,ibionp_arg_coc)),                                                      &
	& SUM(kyrbionp(t,:,ibionp_Corg_tot)),                                                     &
	& SUM(kyrbionp(t,:,ibionp_Corg_tot))  / (SUM(kyrbionp(t,:,ibionp_Feorg_tot)) + 0.000001), &
	& SUM(kyrbionp(t,:,ibionp_opal_dia))  / (SUM(kyrbionp(t,:,ibionp_Corg_dia))  + 0.000001), &
	& SUM(kyrbionp(t,:,ibionp_CaCO3_coc)) / (SUM(kyrbionp(t,:,ibionp_Corg_tot))  + 0.000001), &
	& SUM(kyrbionp(t,:,ibionp_cal_coc))   / (SUM(kyrbionp(t,:,ibionp_Corg_tot))  + 0.000001), &
	& SUM(kyrbionp(t,:,ibionp_arg_coc))   / (SUM(kyrbionp(t,:,ibionp_Corg_tot))  + 0.000001), &
	& calc_d13C(SUM(kyrbionp(t,:,ibionp_Corg_dia)),SUM(kyrbionp(t,:,ibionp_13C_Corg_dia))),   &
	& calc_d13C(SUM(kyrbionp(t,:,ibionp_Corg_coc)),SUM(kyrbionp(t,:,ibionp_13C_Corg_coc))),   &
	& calc_d13C(SUM(kyrbionp(t,:,ibionp_Corg_tot)),SUM(kyrbionp(t,:,ibionp_13C_Corg_tot))),   &
	& calc_d13C(SUM(kyrbionp(t,:,ibionp_cal_coc)),SUM(kyrbionp(t,:,ibionp_13C_cal_coc))),     &
	& calc_d13C(SUM(kyrbionp(t,:,ibionp_arg_coc)),SUM(kyrbionp(t,:,ibionp_13C_arg_coc)))
    END DO
! save spin-up data
    DO t = t_spin_max,1,-1
      WRITE(unit=out,FMT='(I4,7E10.3,F14.3,4F10.3,3F9.3,2F7.3)') (t_spin_max - t + 1) + t_ice_init, &
	& SUM(spinbionp(t,:,ibionp_Corg_dia)),                                                      &
	& SUM(spinbionp(t,:,ibionp_opal_dia)),                                                      &
	& SUM(spinbionp(t,:,ibionp_Corg_coc)),                                                      &
	& SUM(spinbionp(t,:,ibionp_CaCO3_coc)),                                                     &
	& SUM(spinbionp(t,:,ibionp_cal_coc)),                                                       &
	& SUM(spinbionp(t,:,ibionp_arg_coc)),                                                       &
	& SUM(spinbionp(t,:,ibionp_Corg_tot)),                                                      &
	& SUM(spinbionp(t,:,ibionp_Corg_tot))  / (SUM(spinbionp(t,:,ibionp_Feorg_tot)) + 0.000001), &
	& SUM(spinbionp(t,:,ibionp_opal_dia))  / (SUM(spinbionp(t,:,ibionp_Corg_dia))  + 0.000001), &
	& SUM(spinbionp(t,:,ibionp_CaCO3_coc)) / (SUM(spinbionp(t,:,ibionp_Corg_tot))  + 0.000001), &
	& SUM(spinbionp(t,:,ibionp_cal_coc))   / (SUM(spinbionp(t,:,ibionp_Corg_tot))  + 0.000001), &
	& SUM(spinbionp(t,:,ibionp_arg_coc))   / (SUM(spinbionp(t,:,ibionp_Corg_tot))  + 0.000001), &
	& calc_d13C(SUM(spinbionp(t,:,ibionp_Corg_dia)),SUM(spinbionp(t,:,ibionp_13C_Corg_dia))),   &
	& calc_d13C(SUM(spinbionp(t,:,ibionp_Corg_coc)),SUM(spinbionp(t,:,ibionp_13C_Corg_coc))),   &
	& calc_d13C(SUM(spinbionp(t,:,ibionp_Corg_tot)),SUM(spinbionp(t,:,ibionp_13C_Corg_tot))),   &
	& calc_d13C(SUM(spinbionp(t,:,ibionp_cal_coc)),SUM(spinbionp(t,:,ibionp_13C_cal_coc))),     &
	& calc_d13C(SUM(spinbionp(t,:,ibionp_arg_coc)),SUM(spinbionp(t,:,ibionp_13C_arg_coc)))
    END DO
    CLOSE(unit=out)


! *** mean np data ***

! *** calculate mean np data ***
! NOTE: np fluxes in (mol m-2 yr-1)
! NOTE: do not include the spin-up np values
    DO c = 1,n_col
      DO t = t_ice_init,t_ice_max,dt_ice
	bionp_tot(c,:) = bionp_tot(c,:) + kyrbionp(t,c,:) / kyrphys(t,c,1,ip_A_bot)
	t_tot(c) = t_tot(c) + 1
      END DO
      bionp_mean(c,:) = bionp_tot(c,:) / REAL(t_tot(c),KIND=fp_1)
    END DO
! convert units; np fluxes in (umol cm-2 yr-1) except Feorg in (nmol cm-2 yr-1), and d13C in (o/oo)
    DO c = 1,n_col
      bionp_Corg_dia(c)      = conv_mol_umol * bionp_mean(c,ibionp_Corg_dia) / conv_m2_cm2
      bionp_Corg_coc(c)      = conv_mol_umol * bionp_mean(c,ibionp_Corg_coc) / conv_m2_cm2
      bionp_cal_coc(c)       = conv_mol_umol * bionp_mean(c,ibionp_cal_coc) / conv_m2_cm2
      bionp_arg_coc(c)       = conv_mol_umol * bionp_mean(c,ibionp_arg_coc) / conv_m2_cm2
      bionp_opal_dia(c)      = conv_mol_umol * bionp_mean(c,ibionp_opal_dia) / conv_m2_cm2
      bionp_Feorg_tot(c)     = conv_mol_nmol * bionp_mean(c,ibionp_Feorg_tot) / conv_m2_cm2
      bionp_d13C_Corg_dia(c) = calc_d13C(bionp_mean(c,ibionp_Corg_dia),bionp_mean(c,ibionp_13C_Corg_dia))
      bionp_d13C_Corg_coc(c) = calc_d13C(bionp_mean(c,ibionp_Corg_coc),bionp_mean(c,ibionp_13C_Corg_coc))
      bionp_d13C_cal_coc(c)  = calc_d13C(bionp_mean(c,ibionp_cal_coc),bionp_mean(c,ibionp_13C_cal_coc))
      bionp_d13C_arg_coc(c)  = calc_d13C(bionp_mean(c,ibionp_arg_coc),bionp_mean(c,ibionp_13C_arg_coc))
      bionp_DOC_dia(c)       = conv_mol_umol * bionp_mean(c,ibionp_DOC_dia) / conv_m2_cm2
      bionp_DOC_coc(c)       = conv_mol_umol * bionp_mean(c,ibionp_DOC_coc) / conv_m2_cm2
      bionp_DOFe_tot(c)      = conv_mol_nmol * bionp_mean(c,ibionp_DOFe_tot) / conv_m2_cm2
      bionp_d13C_DOC_dia(c)  = calc_d13C(bionp_mean(c,ibionp_DOC_dia),bionp_mean(c,ibionp_13C_DOC_dia))
      bionp_d13C_DOC_coc(c)  = calc_d13C(bionp_mean(c,ibionp_DOC_coc),bionp_mean(c,ibionp_13C_DOC_coc))
    END DO
    
! *** save data ***
! set filename
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_bionp_mean.res"
! open file pipe
    OPEN(unit=out,file=filename,action="write")
! save mean np data over glacial/interglacial cycles
    WRITE(unit=out,FMT='(99F10.3)') (bionp_Corg_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_Corg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_cal_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_arg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_opal_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_Feorg_tot(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_Corg_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_Corg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_cal_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_arg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_DOC_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_DOC_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_DOFe_tot(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_DOC_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_DOC_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(A27)') "------- END OF DATA -------"
! close file pipe
    CLOSE(unit=out)


! *** final np data ***

! *** calculate final np data ***
! NOTE: np fluxes in (mol m-2 yr-1)
    DO c = 1,n_col
      bionp_final(c,:) = kyrbionp(0,c,:) / kyrphys(0,c,1,ip_A_bot)
    END DO
! convert units; np fluxes in (umol cm-2 yr-1) except Feorg in (nmol cm-2 yr-1), and d13C in (o/oo)
    DO c = 1,n_col
      bionp_Corg_dia(c)      = conv_mol_umol * bionp_final(c,ibionp_Corg_dia) / conv_m2_cm2
      bionp_Corg_coc(c)      = conv_mol_umol * bionp_final(c,ibionp_Corg_coc) / conv_m2_cm2
      bionp_cal_coc(c)       = conv_mol_umol * bionp_final(c,ibionp_cal_coc) / conv_m2_cm2
      bionp_arg_coc(c)       = conv_mol_umol * bionp_final(c,ibionp_arg_coc) / conv_m2_cm2
      bionp_opal_dia(c)      = conv_mol_umol * bionp_final(c,ibionp_opal_dia) / conv_m2_cm2
      bionp_Feorg_tot(c)     = conv_mol_nmol * bionp_final(c,ibionp_Feorg_tot) / conv_m2_cm2
      bionp_d13C_Corg_dia(c) = calc_d13C(bionp_final(c,ibionp_Corg_dia),bionp_final(c,ibionp_13C_Corg_dia))
      bionp_d13C_Corg_coc(c) = calc_d13C(bionp_final(c,ibionp_Corg_coc),bionp_final(c,ibionp_13C_Corg_coc))
      bionp_d13C_cal_coc(c)  = calc_d13C(bionp_final(c,ibionp_cal_coc),bionp_final(c,ibionp_13C_cal_coc))
      bionp_d13C_arg_coc(c)  = calc_d13C(bionp_final(c,ibionp_arg_coc),bionp_final(c,ibionp_13C_arg_coc))
      bionp_DOC_dia(c)       = conv_mol_umol * bionp_final(c,ibionp_DOC_dia) / conv_m2_cm2
      bionp_DOC_coc(c)       = conv_mol_umol * bionp_final(c,ibionp_DOC_coc) / conv_m2_cm2
      bionp_DOFe_tot(c)      = conv_mol_nmol * bionp_final(c,ibionp_DOFe_tot) / conv_m2_cm2
      bionp_d13C_DOC_dia(c)  = calc_d13C(bionp_final(c,ibionp_DOC_dia),bionp_final(c,ibionp_13C_DOC_dia))
      bionp_d13C_DOC_coc(c)  = calc_d13C(bionp_final(c,ibionp_DOC_coc),bionp_final(c,ibionp_13C_DOC_coc))
    END DO
    
! *** save data ***
! set filename
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_bionp_final.res"
! open file pipe
    OPEN(unit=out,file=filename,action="write")
! save final np data
    WRITE(unit=out,FMT='(99F10.3)') (bionp_Corg_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_Corg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_cal_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_arg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_opal_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_Feorg_tot(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_Corg_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_Corg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_cal_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_arg_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_DOC_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_DOC_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_DOFe_tot(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_DOC_dia(c),c=1,n_col)
    WRITE(unit=out,FMT='(99F10.3)') (bionp_d13C_DOC_coc(c),c=1,n_col)
    WRITE(unit=out,FMT='(A27)') "------- END OF DATA -------"
! close file pipe
    CLOSE(unit=out)


  END SUBROUTINE save_kyr_bionp_data
! *************************************************


! ************************************************
! *** save (kyr) sediment sub-system flux data ***
! ************************************************
  SUBROUTINE save_kyr_sed_data(ticeinit,sedpar,kyrsedfnp,kyrsedfdis,spinsedfnp,spinsedfdis)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::ticeinit
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_par)::sedpar
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_fnp)::kyrsedfnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_com_par)::kyrsedfdis
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_fnp)::spinsedfnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_com_par)::spinsedfdis
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=2)::col_num,lay_num,sed_num
    INTEGER::c,t,m
    INTEGER::out=1


! *** kyr sediment rain rate sub-system grip point data ***
    
    DO m = 1,n_sed_depth
      sed_num = conv_num_char(m)
      
! *** save data ***
! Corg rain flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fnp_Corg.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                  &
	  & (                                                  &
	  &   kyrsedfnp(t,c,m,ised_fnp_Corg) * conv_mol_umol / &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),          &
	  &   c=1,n_col                                        &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                 &
	  &   spinsedfnp(t,c,m,ised_fnp_Corg) * conv_mol_umol /               &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),                         &
	  &   c=1,n_col                                                       &
	  & )
      END DO
      CLOSE(unit=out)
! Feorg rain flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fnp_Feorg.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                   &
	  & (                                                   &
	  &   kyrsedfnp(t,c,m,ised_fnp_Feorg) * conv_mol_umol / &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),           &
	  &   c=1,n_col                                         &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                 &
	  &   spinsedfnp(t,c,m,ised_fnp_Feorg) * conv_mol_umol /              &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),                         &
	  &   c=1,n_col                                                       &
	  & )
      END DO
      CLOSE(unit=out)
! cal rain flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fnp_cal.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                 &
	  & (                                                 &
	  &   kyrsedfnp(t,c,m,ised_fnp_cal) * conv_mol_umol / &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),         &
	  &   c=1,n_col                                       &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                 &
	  &   spinsedfnp(t,c,m,ised_fnp_cal) * conv_mol_umol /                &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),                         &
	  &   c=1,n_col                                                       &
	  & )
      END DO
      CLOSE(unit=out)
! arg rain flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fnp_arg.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                 &
	  & (                                                 &
	  &   kyrsedfnp(t,c,m,ised_fnp_arg) * conv_mol_umol / &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),         &
	  &   c=1,n_col                                       &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                 &
	  &   spinsedfnp(t,c,m,ised_fnp_arg) * conv_mol_umol /                &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),                         &
	  &   c=1,n_col                                                       &
	  & )
      END DO
      CLOSE(unit=out)
! opal rain flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fnp_opal.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                  &
	  & (                                                  &
	  &   kyrsedfnp(t,c,m,ised_fnp_opal) * conv_mol_umol / &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),          &
	  &   c=1,n_col                                        &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                 &
	  &   spinsedfnp(t,c,m,ised_fnp_opal) * conv_mol_umol /               &
	  &   (sedpar(c,m,ised_par_A) * conv_m2_cm2),                         &
	  &   c=1,n_col                                                       &
	  & )
      END DO
      CLOSE(unit=out)
      
    END DO


! *** kyr sediment dissolution rate sub-system grip point data ***
    
    DO m = 1,n_sed_depth
      sed_num = conv_num_char(m)
      
! *** save data ***
! Corg dissolution flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fdis_Corg.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                                 &
	  & (                                                                  &
	  &   kyrsedfdis(t,c,m,ised_Corg) * conv_Corg_cm3_mol * conv_mol_umol, &
	  &   c=1,n_col                                                        &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init,  &
	  & (                                                                   &
	  &   spinsedfdis(t,c,m,ised_Corg) * conv_Corg_cm3_mol * conv_mol_umol, &
	  &   c=1,n_col                                                         &
	  & )
      END DO
      CLOSE(unit=out)
! Feorg dissolution flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fdis_Feorg.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                               &
	  & (                                                                &
	  &   kyrsedfdis(t,c,m,ised_FeO) * conv_FeO_cm3_mol * conv_mol_umol, &
	  &   c=1,n_col                                                      &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                  &
	  &   spinsedfdis(t,c,m,ised_FeO) * conv_FeO_cm3_mol * conv_mol_umol,  &
	  &   c=1,n_col                                                        &
	  & )
      END DO
      CLOSE(unit=out)
! cal dissolution flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fdis_cal.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                               &
	  & (                                                                &
	  &   kyrsedfdis(t,c,m,ised_cal) * conv_cal_cm3_mol * conv_mol_umol, &
	  &   c=1,n_col                                                      &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                  &
	  &   spinsedfdis(t,c,m,ised_cal) * conv_cal_cm3_mol * conv_mol_umol,  &
	  &   c=1,n_col                                                        &
	  & )
      END DO
      CLOSE(unit=out)
! arg dissolution flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fdis_arg.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                               &
	  & (                                                                &
	  &   kyrsedfdis(t,c,m,ised_arg) * conv_arg_cm3_mol * conv_mol_umol, &
	  &   c=1,n_col                                                      &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & (                                                                  &
	  &   spinsedfdis(t,c,m,ised_arg) * conv_arg_cm3_mol * conv_mol_umol,  &
	  &   c=1,n_col                                                        &
	  & )
      END DO
      CLOSE(unit=out)
! opal dissolution flux
      filename = modelname//"_output/"//modelname//"_kyr_sed"//sed_num//"xx_fdis_opal.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,99E14.6)') t,                                 &
	  & (                                                                  &
	  &   kyrsedfdis(t,c,m,ised_opal) * conv_opal_cm3_mol * conv_mol_umol, &
	  &   c=1,n_col                                                        &
	  & )
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,99E14.6)') (t_spin_max - t + 1) + t_ice_init,  &
	  & (                                                                   &
	  &   spinsedfdis(t,c,m,ised_opal) * conv_opal_cm3_mol * conv_mol_umol, &
	  &   c=1,n_col                                                         &
	  & )
      END DO
      CLOSE(unit=out)
      
    END DO

    
  END SUBROUTINE save_kyr_sed_data
! ************************************************


! *******************************************************
! *** save global (kyr) sediment sub-system flux data ***
! *******************************************************
  SUBROUTINE save_kyr_sed_data_global(ticeinit,sedpar,kyrsedfnp,kyrsedfdis,spinsedfnp,spinsedfdis)
    IMPLICIT NONE
! dummy arguments
    INTEGER,INTENT(in)::ticeinit
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_par)::sedpar
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_fnp)::kyrsedfnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_com_par)::kyrsedfdis
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_fnp)::spinsedfnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_com_par)::spinsedfdis
! local variables
    CHARACTER(LEN=255)::filename
    CHARACTER(LEN=2)::col_num,lay_num,sed_num
    INTEGER::c,t,m
    INTEGER::out=1

! *** kyr sediment sub-system grid point data ***

! *** save settling flux data ***
    DO c = 1,n_col
      col_num = conv_num_char(c)
      filename = modelname//"_output/"//modelname//"_kyr_sed"//col_num//"xx_fsed.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1
	WRITE(unit=out,FMT='(I4,5E14.6)') t,      &
	  & SUM(kyrsedfnp(t,c,:,ised_fnp_Corg)),  &
	  & SUM(kyrsedfnp(t,c,:,ised_fnp_Feorg)), &
	  & SUM(kyrsedfnp(t,c,:,ised_fnp_cal)),   &
	  & SUM(kyrsedfnp(t,c,:,ised_fnp_arg)),   &
	  & SUM(kyrsedfnp(t,c,:,ised_fnp_opal))
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,5E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	  & SUM(spinsedfnp(t,c,:,ised_fnp_Corg)),                            &
	  & SUM(spinsedfnp(t,c,:,ised_fnp_Feorg)),                           &
	  & SUM(spinsedfnp(t,c,:,ised_fnp_cal)),                             &
	  & SUM(spinsedfnp(t,c,:,ised_fnp_arg)),                             &
	  & SUM(spinsedfnp(t,c,:,ised_fnp_opal))
      END DO
    END DO
! *** save dissolution flux data ***
    DO c = 1,n_col
      col_num = conv_num_char(c)
      filename = modelname//"_output/"//modelname//"_kyr_sed"//col_num//"xx_fdis.res"
      OPEN(unit=out,file=filename,action="write")
      DO t = 0,t_ice_init,1 
	WRITE(unit=out,FMT='(I4,5E14.6)') t,                                                             &
	  & SUM(kyrsedfdis(t,c,:,ised_Corg) * conv_Corg_cm3_mol * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(kyrsedfdis(t,c,:,ised_FeO)  * conv_FeO_cm3_mol  * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(kyrsedfdis(t,c,:,ised_cal)  * conv_cal_cm3_mol  * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(kyrsedfdis(t,c,:,ised_arg)  * conv_arg_cm3_mol  * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(kyrsedfdis(t,c,:,ised_opal) * conv_opal_cm3_mol * sedpar(c,:,ised_par_A) * conv_m2_cm2)
      END DO
      DO t = t_spin_max,1,-1
	WRITE(unit=out,FMT='(I4,5E14.6)') (t_spin_max - t + 1) + t_ice_init,                              &
	  & SUM(spinsedfdis(t,c,:,ised_Corg) * conv_Corg_cm3_mol * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(spinsedfdis(t,c,:,ised_FeO)  * conv_FeO_cm3_mol  * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(spinsedfdis(t,c,:,ised_cal)  * conv_cal_cm3_mol  * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(spinsedfdis(t,c,:,ised_arg)  * conv_arg_cm3_mol  * sedpar(c,:,ised_par_A) * conv_m2_cm2), &
	  & SUM(spinsedfdis(t,c,:,ised_opal) * conv_opal_cm3_mol * sedpar(c,:,ised_par_A) * conv_m2_cm2)
      END DO
    END DO
      
! *** kyr sediment sub-system global data ***
      
! save settling flux data
    filename = modelname//"_output/"//modelname//"_kyr_sed_ocean_fnp.res"
    OPEN(unit=out,file=filename,action="write")
    DO t = 0,t_ice_init,1
      WRITE(unit=out,FMT='(I4,5E14.6)') t,      &
	& SUM(kyrsedfnp(t,:,:,ised_fnp_Corg)),  &
	& SUM(kyrsedfnp(t,:,:,ised_fnp_Feorg)), &
	& SUM(kyrsedfnp(t,:,:,ised_fnp_cal)),   &
	& SUM(kyrsedfnp(t,:,:,ised_fnp_arg)),   &
	& SUM(kyrsedfnp(t,:,:,ised_fnp_opal))
    END DO
    DO t = t_spin_max,1,-1
      WRITE(unit=out,FMT='(I4,5E14.6)') (t_spin_max - t + 1) + t_ice_init, &
	& SUM(spinsedfnp(t,:,:,ised_fnp_Corg)),                            &
	& SUM(spinsedfnp(t,:,:,ised_fnp_Feorg)),                           &
	& SUM(spinsedfnp(t,:,:,ised_fnp_cal)),                             &
	& SUM(spinsedfnp(t,:,:,ised_fnp_arg)),                             &
	& SUM(spinsedfnp(t,:,:,ised_fnp_opal))
    END DO
    CLOSE(unit=out)
! save dissolution data
    filename = modelname//"_output/"//modelname//"_kyr_sed_ocean_fdis.res"
    OPEN(unit=out,file=filename,action="write")
    DO t = 0,t_ice_init,1
      WRITE(unit=out,FMT='(I4,5E14.6)') t,                                                             &
	& SUM(kyrsedfdis(t,:,:,ised_Corg) * conv_Corg_cm3_mol * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(kyrsedfdis(t,:,:,ised_FeO)  * conv_FeO_cm3_mol  * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(kyrsedfdis(t,:,:,ised_cal)  * conv_cal_cm3_mol  * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(kyrsedfdis(t,:,:,ised_arg)  * conv_arg_cm3_mol  * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(kyrsedfdis(t,:,:,ised_opal) * conv_opal_cm3_mol * sedpar(:,:,ised_par_A) * conv_m2_cm2)
    END DO
    DO t = t_spin_max,1,-1
      WRITE(unit=out,FMT='(I4,5E14.6)') (t_spin_max - t + 1) + t_ice_init,                              &
	& SUM(spinsedfdis(t,:,:,ised_Corg) * conv_Corg_cm3_mol * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(spinsedfdis(t,:,:,ised_FeO)  * conv_FeO_cm3_mol  * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(spinsedfdis(t,:,:,ised_cal)  * conv_cal_cm3_mol  * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(spinsedfdis(t,:,:,ised_arg)  * conv_arg_cm3_mol  * sedpar(:,:,ised_par_A) * conv_m2_cm2), &
	& SUM(spinsedfdis(t,:,:,ised_opal) * conv_opal_cm3_mol * sedpar(:,:,ised_par_A) * conv_m2_cm2)
    END DO
    CLOSE(unit=out)
    
  END SUBROUTINE save_kyr_sed_data_global
! *******************************************************


! **********************************
! *** save model diagnostic data ***
! **********************************
  SUBROUTINE save_diagnostic_data(phys,sedpar,oatracer,bionp)
    IMPLICIT NONE
! dummy arguments
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::phys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_par)::sedpar
    TYPE(ocean_atm_tracer),INTENT(in)::oatracer
    REAL(KIND=fp_1),DIMENSION(n_col,n_bionp),INTENT(in)::bionp
! local variables
    CHARACTER(LEN=255)::filename
    INTEGER::c,l,m
    INTEGER::out=1
    REAL(KIND=fp_1)::kgastrans_mean_seaice
    REAL(KIND=fp_1)::kgastrans_mean_noseaice
    REAL(KIND=fp_1),DIMENSION(n_col)::seaice
    REAL(KIND=fp_1),DIMENSION(n_col)::fug_CO2,conc_CO2,conc_CO3,conc_HCO3,conc_H
    REAL(KIND=fp_1),DIMENSION(n_col)::pvgas_k_CO2
    REAL(KIND=fp_1),DIMENSION(n_col)::pvgas_Sc_CO2
    REAL(KIND=fp_1),DIMENSION(n_col)::fC_ocn_atm
    REAL(KIND=fp_1),DIMENSION(n_col)::fC_atm_ocn
    REAL(KIND=fp_1),DIMENSION(n_col,n_dis)::SS_dis

! *** calculate mean ocean <-> atmosphere CO2 gas exchange coefficient ***
    IF (miscopt(mopt_uniform_kgastrans) == no) THEN
! estimate mean sea ice extent
      seaice(:) = (phys(:,1,ip_seaice_min) + phys(:,1,ip_seaice_max)) / 2.0
! calculate ocean surface carbonate equilibrium
      DO c = 1,n_col
	CALL co2const_ex(oatracer%ioat_t(c,1,it_T),oatracer%ioat_t(c,1,it_S), &
	  & (phys(c,1,ip_D_top) + phys(c,1,ip_D_top)) / 2.0,SS_dis(c,:))
	conc_H(c) = 7.0E-09 
	CALL calccarb_sur(c,SS_dis(c,:),oatracer%ioat_t(c,1,it_S),oatracer%ioat_t(c,1,it_alk), &
	  & oatracer%ioat_t(c,1,it_CO2),oatracer%ioat_t(c,1,it_PO4),oatracer%ioat_t(c,1,it_Si), &
	  & fug_CO2(c),conc_CO2(c),conc_CO3(c),conc_HCO3(c),conc_H(c))
      END DO
!     calculate Schmidt number for CO2 gas transfer
      pvgas_Sc_CO2(:) = &
	& pvgas_Sc_CO2_A                                     - &
	& pvgas_Sc_CO2_B * (phys(:,1,ip_T) - const_zeroC)    + &
	& pvgas_Sc_CO2_C * (phys(:,1,ip_T) - const_zeroC)**2 - &
	& pvgas_Sc_CO2_D * (phys(:,1,ip_T) - const_zeroC)**3
!     calculate CO2 gas transfer velocity (piston velocity)
!     NOTE: from Wanninkhof [1992] equation 8
!     NOTE: convert from units of (cm hr-1) to (m yr-1)
!     NOTE: correct estimated piston velocity to give a mean global value of 0.061 (mol m-2 uatm-1 yr-1)
!           (from Aumont et al. [1999])
      pvgas_k_CO2(:) = &
      & ( &
      & 2.5 * &
      & ( &
      & pvgas_k_CO2_a                                     + &
      & pvgas_k_CO2_b * (phys(:,1,ip_T) - const_zeroC)    + &
      & pvgas_k_CO2_c * (phys(:,1,ip_T) - const_zeroC)**2   &
      & ) + &
      & 0.38 * phys(:,1,ip_swind)**2 &
      & ) * &
      & (pvgas_Sc_CO2(:) / 660.0)**(-0.5)
      pvgas_k_CO2(:) = conv_cm_m * conv_yr_hr * pvgas_k_CO2(:)
!     calculate mean global CO2 gas exchange coefficient
!     NOTE: units of (mol m-2 uatm-1 yr-1)
      kgastrans_mean_seaice   = (conv_m3_kg / conv_mol_umol) * &
	& SUM(SS_dis(:,idis_QCO2) * pvgas_k_CO2(:) * (1.0 - seaice) * phys(:,1,ip_A_top)) / &
	& SUM((1.0 - seaice) * phys(:,1,ip_A_top))
      kgastrans_mean_noseaice = (conv_m3_kg / conv_mol_umol) * &
	& SUM(SS_dis(:,idis_QCO2) * pvgas_k_CO2(:) * (1.0 - 0.0)    * phys(:,1,ip_A_top)) / &
	& SUM((1.0 - 0.0)    * phys(:,1,ip_A_top))
    ELSE
      kgastrans_mean_seaice   = par_misc_kgastrans_coeff_CO2
      kgastrans_mean_noseaice = par_misc_kgastrans_coeff_CO2
    END IF

! *** save general diagnostic data ***
! set filename
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_general.res"
! open file pipe
    OPEN(unit=out,file=filename,action="write")
! save data
    WRITE(unit=out,FMT='(A1)') " "
    WRITE(unit=out,FMT='(A42,F10.6)') &
      & " > Global ocean surface area (10^14 m2) : ", &
      & SUM(phys(:,1,ip_A_top)) * 1.0E-14
    WRITE(unit=out,FMT='(A42,F10.6)') &
      & " > Global ocean volume (10^18 m3)       : ", &
      & SUM(phys(:,:,ip_V)) * 1.0E-18
    WRITE(unit=out,FMT='(A1)') " "
    WRITE(unit=out,FMT='(A76,F10.6)') &
      & " > Mean CO2 gas exchange coefficient [exc. sea ice] (mol m-2 uatm-1 yr-1) : ", &
      & kgastrans_mean_noseaice
    WRITE(unit=out,FMT='(A76,F10.6)') &
      & " > Mean CO2 gas exchange coefficient [inc. sea ice] (mol m-2 uatm-1 yr-1) : ", &
      & kgastrans_mean_seaice
! close file pipe
    CLOSE(unit=out)

! *** save general grid point data ***
! set filename
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_gridpt.res"
! open file pipe
    OPEN(unit=out,file=filename,action="write")
! save data
    WRITE(unit=out,FMT='(A1)') " "
    WRITE(unit=out,FMT='(A25,99I15)') &
      & " Grid point identifier : ", &
      & (c,c=1,n_col)
    WRITE(unit=out,FMT='(A1)') " "
    WRITE(unit=out,FMT='(A25,99E15.6)') &
      & " > Volume (m3)         : ", &
      & (SUM(phys(c,:,ip_V)),c=1,n_col)
    WRITE(unit=out,FMT='(A1)') " "
    WRITE(unit=out,FMT='(A25,99E15.6)') &
      & " > Surface area (m2)   : ", &
      & (phys(c,1,ip_A_top),c=1,n_col)
! close file pipe
    CLOSE(unit=out)

! *** save general sediment sub-system data ***
! set filename
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_sedsys.res"
! open file pipe
    OPEN(unit=out,file=filename,action="write")
! write data
    WRITE(unit=out,FMT='(2A3,4A12)'), &
      & "c", &
      & "m", &
      & "depth", &
      & "area", &
      & "%area", &
      & "%area (np)"
    DO c = 1,n_col
      DO m = 1,n_sed_depth
	WRITE(unit=out,FMT='(2I3,F12.3,E12.3,2F12.3)'), &
	  & c, &
	  & m, &
	  & sedpar(c,m,ised_par_D_mid), &
	  & sedpar(c,m,ised_par_A), &
	  & sedpar(c,m,ised_par_Afrac) * 100.0, &
	  & sedpar(c,m,ised_par_Afrac_np) * 100.0
      END DO
    END DO
! close file pipe
    CLOSE(unit=out)
    
! *** save np data (global) ***
! NOTE: global new production details
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_globalnp.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(A38,F10.3)') "Diatom POM np (GtC yr-1) :            ", &
      & SUM(bionp(:,ibionp_Corg_dia)) * conv_C_mol_kg * 1.0E-12
    WRITE(unit=out,FMT='(A38,F10.3)') "Diatom opal np (Tmol yr-1) :          ", &
      & SUM(bionp(:,ibionp_opal_dia)) * 1.0E-12
    WRITE(unit=out,FMT='(A38,F10.3)') "Coccolithophore POM np (GtC yr-1) :   ", &
      & SUM(bionp(:,ibionp_Corg_coc)) * conv_C_mol_kg * 1.0E-12
    WRITE(unit=out,FMT='(A38,F10.3)') "Coccolithophore CaCO3 np (GtC yr-1) : ", &
      & SUM(bionp(:,ibionp_CaCO3_coc)) * conv_CaCO3_mol_kgC * 1.0E-12
    WRITE(unit=out,FMT='(A38,F10.3)') "Total POM np (GtC yr-1) :             ", &
      & SUM(bionp(:,ibionp_Corg_tot)) * conv_C_mol_kg * 1.0E-12
    WRITE(unit=out,FMT='(A38,F10.3)') "CaCO3:POM rain ratio :                ", &
      & SUM(bionp(:,ibionp_CaCO3_coc)) / (0.000001 + SUM(bionp(:,ibionp_Corg_tot)))
    WRITE(unit=out,FMT='(A38,F10.3)') "Total DOC np (GtC yr-1) :             ", &
      & SUM(bionp(:,ibionp_DOC_tot)) * conv_C_mol_kg * 1.0E-12
    CLOSE(unit=out)
    
! *** save atmospheric data ***
    filename = modelname//"_output/"//modelname//"_000kaBP_diagnostics_atm.res"
    OPEN(unit=out,file=filename,action="WRITE")
    WRITE(unit=out,FMT='(A38,F10.3)') "pCO2 (ppmv)      : ", &
      & oatracer%ioat_a(ia_pCO2) * 1.0E+06
    WRITE(unit=out,FMT='(A38,F10.3)') "d13C pCO2 (o/oo) : ", &
      & calc_d13C(oatracer%ioat_a(ia_pCO2),oatracer%ioat_a(ia_13C_pCO2))
    WRITE(unit=out,FMT='(A38,F10.3)') "pO2 (ppmv)       : ", &
      & oatracer%ioat_a(ia_pO2) * 1.0E+06
    WRITE(unit=out,FMT='(A38,F10.3)') "d18O pO2 (o/oo)  : ", &
      & calc_d18O(oatracer%ioat_a(ia_pO2),oatracer%ioat_a(ia_18O_pO2))
    CLOSE(unit=out)

  END SUBROUTINE save_diagnostic_data
! **********************************



! *************************************************************************************************
! *** SCREEN DISPLAY PROCEDURES *******************************************************************
! *************************************************************************************************


! ********************************************************************
! *** print out end-of-simulation results for (xxxx configuration) ***
! ********************************************************************
  SUBROUTINE print_finaldata_xxxx(ticeinit,dtotper)
! dummy arguments
    INTEGER,INTENT(in)::ticeinit
    REAL(KIND=fp_1),INTENT(inout),DIMENSION(n_tracer)::dtotper
! print out results
    PRINT'("        * Start simuluation time (yrs BP) = ",F14.3)',1000.0 * ticeinit
    PRINT'("        * Total simuluation time (yrs)    = ",F14.3)',1000.0 * (ticeinit + t_spin_max)
    PRINT*,""
    PRINT'("        * Ocean-atmosphere geochemical inventory drift (%)")'
    PRINT'("        * d(CO2)      = ",E14.3)',dtotper(it_CO2)
    PRINT'("        * d(13CO2)    = ",E14.3)',dtotper(it_13C_CO2)
    PRINT'("        * d(O2)       = ",E14.3)',dtotper(it_O2)
    PRINT'("        * d(18O2)     = ",E14.3)',dtotper(it_18O_O2)
    PRINT'("        * d(PO4)      = ",E14.3)',dtotper(it_PO4)
    PRINT'("        * d(alk)      = ",E14.3)',dtotper(it_alk)
    PRINT'("        * d(Si)       = ",E14.3)',dtotper(it_Si)
    PRINT'("        * d(Fe)       = ",E14.3)',dtotper(it_Fe)
    PRINT'("        * d(salinity) = ",E14.3)',dtotper(it_S)
    PRINT'("        * d(T)        = ",E14.3)',dtotper(it_T)
  END SUBROUTINE print_finaldata_xxxx
! ********************************************************************


! **********************
! *** 'tracer' DEBUG ***
! **********************
  SUBROUTINE print_tracer(oatracer)
! NOTE: surface boxes only
! dummy arguments
    TYPE(ocean_atm_tracer),INTENT(in)::oatracer
! print values
    PRINT'(" SUM CO2      --> ",3E16.6)',oatracer%ioat_t(:,:,it_CO2)
    PRINT'(" SUM PO4      --> ",3E16.6)',oatracer%ioat_t(:,:,it_PO4)
    PRINT'(" Alkalinity   --> ",3E16.6)',oatracer%ioat_t(:,:,it_alk)
    PRINT'(" [Si]         --> ",3E16.6)',oatracer%ioat_t(:,:,it_Si)
  END SUBROUTINE print_tracer
! **********************


! *******************************
! *** print spin-step results ***
! *******************************
  SUBROUTINE print_spinstepdata(oatracer,phys,bionp,tspin,tloop)
! dummy arguments
    TYPE(ocean_atm_tracer),INTENT(in)::oatracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::phys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_bionp)::bionp
    INTEGER,INTENT(in)::tspin,tloop
! print spin-step data
    PRINT'("        * ",F7.3,F9.3,F8.3,2F8.1,2F10.3,F9.3)', &
      & (tspin - 1) + (tloop / 1000.0), &
      & oatracer%ioat_a(ia_pCO2) * 1.0E6, &
      & calc_d13C(oatracer%ioat_a(ia_pCO2),oatracer%ioat_a(ia_13C_pCO2)), &
      & SUM(phys(:,:,ip_D_calsat) * phys(:,:,ip_V)) / SUM(phys(:,:,ip_V)), &
      & SUM(phys(:,:,ip_D_argsat) * phys(:,:,ip_V)) / SUM(phys(:,:,ip_V)), &
      & 1.0E6 * SUM(oatracer%ioat_t(:,:,it_CO2) * phys(:,:,ip_M)) / SUM(phys(:,:,ip_M)), &
      & 1.0E6 * SUM(oatracer%ioat_t(:,:,it_alk) * phys(:,:,ip_M)) / SUM(phys(:,:,ip_M)), &
      & 1.0E6 * SUM(oatracer%ioat_t(:,:,it_Si)  * phys(:,:,ip_M)) / SUM(phys(:,:,ip_M))
  END SUBROUTINE print_spinstepdata
! *******************************


! ******************************
! *** print kyr-step results ***
! ******************************
  SUBROUTINE print_kyrstepdata(oatracer,phys,bionp,tice,tloop)
! dummy arguments
    TYPE(ocean_atm_tracer),INTENT(in)::oatracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::phys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_bionp)::bionp
    INTEGER,INTENT(in)::tice,tloop
! print kyr-step data:
! (1) time (kyr BP)
! (2) pCO2 (ppmv)
! (3) d13C pCO2 (o/oo)
! (4) average ocean basin calcite lysocline depth (m)
! (5) average ocean basin aragonite lysocline depth (m)
    PRINT'("        * ",F7.3,F9.3,F8.3,2F8.1,2F10.3,F9.3)', &
      & REAL(tice,KIND=fp_1) - (tloop / 1000.0), &
      & oatracer%ioat_a(ia_pCO2) * 1.0E6, &
      & calc_d13C(oatracer%ioat_a(ia_pCO2),oatracer%ioat_a(ia_13C_pCO2)), &
      & SUM(phys(:,:,ip_D_calsat) * phys(:,:,ip_V)) / SUM(phys(:,:,ip_V)), &
      & SUM(phys(:,:,ip_D_argsat) * phys(:,:,ip_V)) / SUM(phys(:,:,ip_V)), &
      & 1.0E6 * SUM(oatracer%ioat_t(:,:,it_CO2) * phys(:,:,ip_M)) / SUM(phys(:,:,ip_M)), &
      & 1.0E6 * SUM(oatracer%ioat_t(:,:,it_alk) * phys(:,:,ip_M)) / SUM(phys(:,:,ip_M)), &
      & 1.0E6 * SUM(oatracer%ioat_t(:,:,it_Si)  * phys(:,:,ip_M)) / SUM(phys(:,:,ip_M))
  END SUBROUTINE print_kyrstepdata
! ******************************


! *************************************************************************************************



! *************************************************************************************************
! *** MODEL RUN CONTROL ***************************************************************************
! *************************************************************************************************

  
! **************************
! *** save all variables ***
! **************************
  SUBROUTINE save_all(&
    & t_ice_save, &
    & sur_disconst, &
    & sur_carbchem, &
    & ocean_cir, &
    & oatracer, &
    & phys, &
    & bio_np, &
    & bio_np_fixed, &
    & o_conv_adj, &
    & o_conv_adj_fixed, &
    & sealevel, &
    & ocir, &
    & SST, &
    & SSS, &
    & SSPO4, &
    & fterr, &
    & fneri, &
    & fdust, &
    & frefrac, &
    & fdust_Fe_dis, &
    & fSi, &
    & foat_gaia, &
    & PIG_oatracer, &
    & PIG_phys, &
    & tracer_tot, &
    & tracer_tot_init, &
    & dtracer_tot, &
    & dtracer_tot_per, &
    & d_dtracer_tot, &
    & oatracer_annual, &
    & sed, &
    & sed_top, &
    & sed_par, &
    & sed_fnp, &
    & sed_disconst, &
    & sed_tracer, &
    & sed_fdis, &
    & bath_data, &
    & spec_d18Onorm, &
    & kyr_oatracer, &
    & kyr_phys, &
    & kyr_bionp, &
    & kyr_o_conv_adj, &
    & kyr_sed_fnp, &
    & kyr_sed_fdis, &
    & spin_oatracer, &
    & spin_phys, &
    & spin_bionp, &
    & spin_o_conv_adj, &
    & spin_sed_fnp, &
    & spin_sed_fdis, &
    & kyr_foat_gaia, &
    & sedcor, &
    & sedcor_top, &
    & sedcor_par, &
    & sedcor_disconst, &
    & sedcor_tracer, &
    & sedcor_fnp, &
    & sedcor_fdis, &
    & warning &
    & )
! dummy arguments
    INTEGER::t_ice_save
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_dis)::sur_disconst
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sscc)::sur_carbchem
    TYPE(ocean_circulation),INTENT(in),DIMENSION(n_wflux_max)::ocean_cir
    TYPE(ocean_atm_tracer),INTENT(in)::oatracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::phys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_bionp)::bio_np
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_bionp)::bio_np_fixed
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_t_int_max)::o_conv_adj
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_t_int_max)::o_conv_adj_fixed
    REAL(KIND=fp_1),INTENT(in)::sealevel
    REAL(KIND=fp_1),INTENT(in)::ocir
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col)::SST
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col)::SSS
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col)::SSPO4
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_tracer)::fterr
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_tracer)::fneri
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col)::fdust
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col)::frefrac
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col)::fdust_Fe_dis
    REAL(KIND=fp_1),INTENT(in)::fSi
    TYPE(ocean_atm_tracer),INTENT(in)::foat_gaia
    TYPE(ocean_atm_tracer),INTENT(in)::PIG_oatracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_lay,n_phys)::PIG_phys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_tracer)::tracer_tot,tracer_tot_init
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_tracer)::dtracer_tot,dtracer_tot_per
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_tracer)::d_dtracer_tot
    TYPE(ocean_atm_tracer),INTENT(in)::oatracer_annual
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_tot,n_sed_com_par)::sed
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_com_par)::sed_top
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_par)::sed_par
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_fnp)::sed_fnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_dis)::sed_disconst
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_tracer)::sed_tracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_sed_depth,n_sed_com_par)::sed_fdis
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_col,n_bath_depth,n_bath_par)::bath_data
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr)::spec_d18Onorm
    TYPE(ocean_atm_tracer),INTENT(in),DIMENSION(0:n_kyr)::kyr_oatracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_lay,n_phys_kyr)::kyr_phys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_bionp)::kyr_bionp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_lay,n_t_int_max)::kyr_o_conv_adj
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_fnp)::kyr_sed_fnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_com_par)::kyr_sed_fdis
    TYPE(ocean_atm_tracer),INTENT(in),DIMENSION(n_spin)::spin_oatracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_lay,n_phys_spin)::spin_phys
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_bionp)::spin_bionp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_lay,n_t_int_max)::spin_o_conv_adj
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_fnp)::spin_sed_fnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_com_par)::spin_sed_fdis
    TYPE(ocean_atm_tracer),INTENT(in),DIMENSION(0:n_kyr)::kyr_foat_gaia
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_sedcor,n_sedcor_tot,n_sed_com_par)::sedcor
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_sedcor,n_sed_com_par)::sedcor_top
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_sedcor,n_sed_par)::sedcor_par
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_sedcor,n_dis)::sedcor_disconst
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_sedcor,n_tracer)::sedcor_tracer
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_sedcor,n_sed_fnp)::sedcor_fnp
    REAL(KIND=fp_1),INTENT(in),DIMENSION(n_sedcor,n_sed_fnp)::sedcor_fdis
    CHARACTER(LEN=1),INTENT(in),DIMENSION(10)::warning
    
! *** local variables ***
! file I/O
    INTEGER::out = 12
    
! *** data dump ***
    
    OPEN(unit=out,status="replace",file=modelname//"_savedstate.dat",form="unformatted",action="write")
    WRITE(unit=out) &
      & t_ice_save, &
      & sur_disconst, &
      & sur_carbchem, &
      & ocean_cir, &
      & oatracer, &
      & phys, &
      & bio_np, &
      & bio_np_fixed, &
      & o_conv_adj, &
      & o_conv_adj_fixed, &
      & sealevel, &
      & ocir, &
      & SST, &
      & SSS, &
      & SSPO4, &
      & fterr, &
      & fneri, &
      & fdust, &
      & frefrac, &
      & fdust_Fe_dis, &
      & fSi, &
      & foat_gaia, &
      & PIG_oatracer, &
      & PIG_phys, &
      & tracer_tot, &
      & tracer_tot_init, &
      & dtracer_tot, &
      & dtracer_tot_per, &
      & d_dtracer_tot, &
      & oatracer_annual, &
      & sed, &
      & sed_top, &
      & sed_par, &
      & sed_fnp, &
      & sed_disconst, &
      & sed_tracer, &
      & sed_fdis, &
      & bath_data, &
      & spec_d18Onorm, &
      & kyr_oatracer, &
      & kyr_phys, &
      & kyr_bionp, &
      & kyr_o_conv_adj, &
      & kyr_sed_fnp, &
      & kyr_sed_fdis, &
      & spin_oatracer, &
      & spin_phys, &
      & spin_bionp, &
      & spin_o_conv_adj, &
      & spin_sed_fnp, &
      & spin_sed_fdis, &
      & kyr_foat_gaia, &
      & sedcor, &
      & sedcor_top, &
      & sedcor_par, &
      & sedcor_disconst, &
      & sedcor_tracer, &
      & sedcor_fnp, &
      & sedcor_fdis, &
      & warning
    CLOSE(unit=out)
    
  END SUBROUTINE save_all
! **************************


! **************************
! *** load all variables ***
! **************************
  SUBROUTINE load_all(&
    & t_ice_load, &
    & sur_disconst, &
    & sur_carbchem, &
    & ocean_cir, &
    & oatracer, &
    & phys, &
    & bio_np, &
    & bio_np_fixed, &
    & o_conv_adj, &
    & o_conv_adj_fixed, &
    & sealevel, &
    & ocir, &
    & SST, &
    & SSS, &
    & SSPO4, &
    & fterr, &
    & fneri, &
    & fdust, &
    & frefrac, &
    & fdust_Fe_dis, &
    & fSi, &
    & foat_gaia, &
    & PIG_oatracer, &
    & PIG_phys, &
    & tracer_tot, &
    & tracer_tot_init, &
    & dtracer_tot, &
    & dtracer_tot_per, &
    & d_dtracer_tot, &
    & oatracer_annual, &
    & sed, &
    & sed_top, &
    & sed_par, &
    & sed_fnp, &
    & sed_disconst, &
    & sed_tracer, &
    & sed_fdis, &
    & bath_data, &
    & spec_d18Onorm, &
    & kyr_oatracer, &
    & kyr_phys, &
    & kyr_bionp, &
    & kyr_o_conv_adj, &
    & kyr_sed_fnp, &
    & kyr_sed_fdis, &
    & spin_oatracer, &
    & spin_phys, &
    & spin_bionp, &
    & spin_o_conv_adj, &
    & spin_sed_fnp, &
    & spin_sed_fdis, &
    & kyr_foat_gaia, &
    & sedcor, &
    & sedcor_top, &
    & sedcor_par, &
    & sedcor_disconst, &
    & sedcor_tracer, &
    & sedcor_fnp, &
    & sedcor_fdis, &
    & warning &
    & )
! dummy arguments
    INTEGER,INTENT(out)::t_ice_load
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_dis)::sur_disconst
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sscc)::sur_carbchem
    TYPE(ocean_circulation),INTENT(out),DIMENSION(n_wflux_max)::ocean_cir
    TYPE(ocean_atm_tracer),INTENT(out)::oatracer
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_lay,n_phys)::phys
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_bionp)::bio_np
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_bionp)::bio_np_fixed
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_lay,n_t_int_max)::o_conv_adj
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_lay,n_t_int_max)::o_conv_adj_fixed
    REAL(KIND=fp_1),INTENT(out)::sealevel
    REAL(KIND=fp_1),INTENT(out)::ocir
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col)::SST
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col)::SSS
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col)::SSPO4
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_tracer)::fterr
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_tracer)::fneri
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col)::fdust
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col)::frefrac
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col)::fdust_Fe_dis
    REAL(KIND=fp_1),INTENT(out)::fSi
    TYPE(ocean_atm_tracer),INTENT(out)::foat_gaia
    TYPE(ocean_atm_tracer),INTENT(out)::PIG_oatracer
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_lay,n_phys)::PIG_phys
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_tracer)::tracer_tot,tracer_tot_init
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_tracer)::dtracer_tot,dtracer_tot_per
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_tracer)::d_dtracer_tot
    TYPE(ocean_atm_tracer),INTENT(out)::oatracer_annual
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sed_depth,n_sed_tot,n_sed_com_par)::sed
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sed_depth,n_sed_com_par)::sed_top
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sed_depth,n_sed_par)::sed_par
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sed_depth,n_sed_fnp)::sed_fnp
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sed_depth,n_dis)::sed_disconst
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sed_depth,n_tracer)::sed_tracer
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_sed_depth,n_sed_com_par)::sed_fdis
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_col,n_bath_depth,n_bath_par)::bath_data
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_kyr)::spec_d18Onorm
    TYPE(ocean_atm_tracer),INTENT(out),DIMENSION(0:n_kyr)::kyr_oatracer
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_kyr,n_col,n_lay,n_phys_kyr)::kyr_phys
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_kyr,n_col,n_bionp)::kyr_bionp
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_kyr,n_col,n_lay,n_t_int_max)::kyr_o_conv_adj
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_fnp)::kyr_sed_fnp
    REAL(KIND=fp_1),INTENT(out),DIMENSION(0:n_kyr,n_col,n_sed_depth,n_sed_com_par)::kyr_sed_fdis
    TYPE(ocean_atm_tracer),INTENT(out),DIMENSION(n_spin)::spin_oatracer
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_spin,n_col,n_lay,n_phys_spin)::spin_phys
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_spin,n_col,n_bionp)::spin_bionp
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_spin,n_col,n_lay,n_t_int_max)::spin_o_conv_adj
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_fnp)::spin_sed_fnp
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_spin,n_col,n_sed_depth,n_sed_com_par)::spin_sed_fdis
    TYPE(ocean_atm_tracer),INTENT(out),DIMENSION(0:n_kyr)::kyr_foat_gaia
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_sedcor,n_sedcor_tot,n_sed_com_par)::sedcor
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_sedcor,n_sed_com_par)::sedcor_top
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_sedcor,n_sed_par)::sedcor_par
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_sedcor,n_dis)::sedcor_disconst
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_sedcor,n_tracer)::sedcor_tracer
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_sedcor,n_sed_fnp)::sedcor_fnp
    REAL(KIND=fp_1),INTENT(out),DIMENSION(n_sedcor,n_sed_fnp)::sedcor_fdis
    CHARACTER(LEN=1),INTENT(out),DIMENSION(10)::warning
    
! *** local variables ***
! file I/O
    INTEGER::in = 11
    
! *** data load ***
    
    OPEN(unit=in,status="old",file=modelname//"_savedstate.dat",form="unformatted",action="read")
    READ(unit=in) &
      & t_ice_load, &
      & sur_disconst, &
      & sur_carbchem, &
      & ocean_cir, &
      & oatracer, &
      & phys, &
      & bio_np, &
      & bio_np_fixed, &
      & o_conv_adj, &
      & o_conv_adj_fixed, &
      & sealevel, &
      & ocir, &
      & SST, &
      & SSS, &
      & SSPO4, &
      & fterr, &
      & fneri, &
      & fdust, &
      & frefrac, &
      & fdust_Fe_dis, &
      & fSi, &
      & foat_gaia, &
      & PIG_oatracer, &
      & PIG_phys, &
      & tracer_tot, &
      & tracer_tot_init, &
      & dtracer_tot, &
      & dtracer_tot_per, &
      & d_dtracer_tot, &
      & oatracer_annual, &
      & sed, &
      & sed_top, &
      & sed_par, &
      & sed_fnp, &
      & sed_disconst, &
      & sed_tracer, &
      & sed_fdis, &
      & bath_data, &
      & spec_d18Onorm, &
      & kyr_oatracer, &
      & kyr_phys, &
      & kyr_bionp, &
      & kyr_o_conv_adj, &
      & kyr_sed_fnp, &
      & kyr_sed_fdis, &
      & spin_oatracer, &
      & spin_phys, &
      & spin_bionp, &
      & spin_o_conv_adj, &
      & spin_sed_fnp, &
      & spin_sed_fdis, &
      & kyr_foat_gaia, &
      & sedcor, &
      & sedcor_top, &
      & sedcor_par, &
      & sedcor_disconst, &
      & sedcor_tracer, &
      & sedcor_fnp, &
      & sedcor_fdis, &
      & warning
    CLOSE(unit=in)
    
  END SUBROUTINE load_all
! **************************


! *************************************************************************************************




END MODULE sue_data




